@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -660,7 +660,7 @@ static void put_frame_ioctl(bg_vloopback_t * v, gavl_video_frame_t * frame)
     
     v->output_open = 1;
     
-    ioctl_nr = *(unsigned long*)(buffer);
+    memcpy(&ioctl_nr, buffer, sizeof(ioctl_nr));
     arg = &buffer[sizeof(unsigned long)];
 
     if(!ioctl_nr)
