@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -416,8 +416,8 @@ gmerlin_webcam_window_create(gmerlin_webcam_t * w,
                              ret, "Camelot");
   
   gmerlin_webcam_get_message_queues(ret->cam,
-                                    &(ret->cmd_queue),
-                                    &(ret->msg_queue));
+                                    &ret->cmd_queue,
+                                    &ret->msg_queue);
   
   ret->plugin_reg = reg;
   
