@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -89,7 +89,7 @@ static void grab_key(edit_dialog_t * dlg)
     if(evt.type != KeyPress)
       continue;
 
-    XLookupString(&(evt.xkey), &key_char, 1, &keysym, NULL);
+    XLookupString(&evt.xkey, &key_char, 1, &keysym, NULL);
     
     switch(keysym)
       {
