@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -218,6 +218,7 @@ static const bg_parameter_info_t input_plugin_parameters[] =
     {
       .name = "input_plugins",
       .long_name = "Input plugins",
+      .flags = BG_PARAMETER_PLUGIN,
     },
     { /* */ },
   };
@@ -227,6 +228,7 @@ static const bg_parameter_info_t image_reader_parameters[] =
     {
       .name = "image_readers",
       .long_name = "Image readers",
+      .flags = BG_PARAMETER_PLUGIN,
     },
     { /* */ },
   };
@@ -345,7 +347,7 @@ gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
     
   player_window_create(ret);
   
-  //  gmerlin_skin_load(&(ret->skin), "Default");
+  //  gmerlin_skin_load(&ret->skin, "Default");
   //  gmerlin_skin_set(ret);
 
   /* Create subwindows */
@@ -441,7 +443,7 @@ void gmerlin_destroy(gmerlin_t * g)
   bg_plugin_registry_destroy(g->plugin_reg);
 
   
-  gmerlin_skin_destroy(&(g->skin));
+  gmerlin_skin_destroy(&g->skin);
   
   free(g->skin_dir);
   
@@ -507,7 +509,7 @@ void gmerlin_skin_destroy(gmerlin_skin_t * s)
   {
   if(s->directory)
     free(s->directory);
-  player_window_skin_destroy(&(s->playerwindow));
+  player_window_skin_destroy(&s->playerwindow);
   
   }
 
@@ -867,7 +869,7 @@ void gmerlin_set_parameter(void * data, const char * name,
   else if(!strcmp(name, "skin_dir"))
     {
     g->skin_dir = bg_strdup(g->skin_dir, val->val_str);
-    g->skin_dir = gmerlin_skin_load(&(g->skin), g->skin_dir);
+    g->skin_dir = gmerlin_skin_load(&g->skin, g->skin_dir);
     gmerlin_skin_set(g);
     }
   }
