@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -224,7 +224,7 @@ int main(int argc, char ** argv)
     input_plugin->start(input_handle->priv);
 
   /* Get video format */
-  memcpy(&input_format, &(info->video_streams[0].format),
+  memcpy(&input_format, &info->video_streams[0].format,
          sizeof(input_format));
 
   /* Get the output format */
