@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -660,7 +660,6 @@ static void target_received_func(GtkClipboard *clipboard,
       return;
     else if(!strcmp(atom_name, cp_tracks_name))
       {
-      fprintf(stderr, "Paste tracks\n");
       gtk_clipboard_request_contents(clipboard,
                                      atoms[i],
                                      clipboard_received_func_tracks,
@@ -935,7 +934,7 @@ static void button_callback(GtkWidget * w, gpointer data)
                                      &track_duration, &track_duration_total);
 
     
-    bg_gtk_chapter_dialog_show(&(t->selected_track->chapter_list),
+    bg_gtk_chapter_dialog_show(&t->selected_track->chapter_list,
                                track_duration, t->treeview);
     }
   else if((w == t->encoder_button) ||
