@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -579,7 +579,26 @@ static void about_window_close_callback(bg_gtk_about_window_t * w,
 void transcoder_window_load_profile(transcoder_window_t * win,
                                     const char * file)
   {
+  bg_cfg_section_t * s;
   bg_cfg_registry_load(win->cfg_reg, file);
+  
+  s =
+    bg_encoder_section_get_from_registry(win->plugin_reg,
+                                         win->encoder_parameters,
+                                         stream_flags, plugin_flags);
+  
+  bg_cfg_section_transfer(s, win->encoder_section);
+  bg_cfg_section_destroy(s);
+  }
+
+static void transcoder_window_save_profile(transcoder_window_t * win,
+                                           const char * file)
+  {
+  bg_encoder_section_store_in_registry(win->plugin_reg,
+                                       win->encoder_section,
+                                       win->encoder_parameters,
+                                       stream_flags, plugin_flags);
+  bg_cfg_registry_save(win->cfg_reg, file);
   }
 
 static void button_callback(GtkWidget * w, gpointer data)
@@ -672,7 +691,7 @@ static void button_callback(GtkWidget * w, gpointer data)
                                            &win->profile_path, 1, win->win);
     if(tmp_string)
       {
-      bg_cfg_registry_save(win->cfg_reg, tmp_string);
+      transcoder_window_save_profile(win, tmp_string);
       free(tmp_string);
       }
     }
@@ -1193,6 +1212,7 @@ static const bg_parameter_info_t input_plugin_parameters[] =
     {
       .name = "input_plugins",
       .long_name = "Input plugins",
+      .flags = BG_PARAMETER_PLUGIN,
     },
     { /* */ },
   };
@@ -1202,6 +1222,7 @@ static const bg_parameter_info_t image_reader_parameters[] =
     {
       .name = "image_readers",
       .long_name = "Image readers",
+      .flags = BG_PARAMETER_PLUGIN,
     },
     { /* */ },
   };
