@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -150,7 +150,7 @@ static gboolean configure_callback(GtkWidget * w, GdkEventConfigure *event,
   win->width = event->width;
   win->height = event->height;
   gdk_window_get_root_origin(win->current_window->window->window,
-                             &(win->x), &(win->y));
+                             &win->x, &win->y);
   return FALSE;
   }
 
@@ -387,7 +387,7 @@ static void grab_notify_callback(GtkWidget *widget,
   visualizer_t * win = (visualizer_t*)data;
   if(!was_grabbed)
     {
-    GTK_WIDGET_SET_FLAGS(win->current_window->socket, GTK_CAN_FOCUS);
+    bg_gtk_widget_set_can_focus(win->current_window->socket, TRUE);
     gtk_widget_grab_focus(win->current_window->socket);
     }
   }
@@ -457,7 +457,7 @@ static void plug_added_callback(GtkWidget * w, gpointer data)
   gtk_widget_hide(v->toolbar);
   
   /* Seems that this is switched off, when an earlier client exited */
-  GTK_WIDGET_SET_FLAGS(w, GTK_CAN_FOCUS);
+  bg_gtk_widget_set_can_focus(w, TRUE);
   gtk_widget_grab_focus(w);
   }
 
@@ -556,7 +556,7 @@ static void plugin_window_init(plugin_window_t * win, visualizer_t * v)
   gtk_container_add(GTK_CONTAINER(win->window),  table);
   }
 
-static int motion_callback(void * data, int x, int y)
+static int motion_callback(void * data, int x, int y, int mask)
   {
   visualizer_t * v = (visualizer_t*)data;
   if(v->toolbar_trigger & TOOLBAR_TRIGGER_MOUSE)
@@ -593,6 +593,16 @@ static gboolean key_callback(GtkWidget * w,
   return FALSE;
   }
 
+static gboolean window_motion_callback(GtkWidget      *widget,
+                                       GdkEventMotion *event,
+                                       gpointer        data)
+  {
+  visualizer_t * v = (visualizer_t*)data;
+  if(v->toolbar_trigger & TOOLBAR_TRIGGER_MOUSE)
+    show_toolbar(v);
+  return FALSE;
+  }
+
 static void window_init(visualizer_t * v,
                         window_t * w, int fullscreen)
   {
@@ -616,10 +626,13 @@ static void window_init(visualizer_t * v,
                             0, 1, 0, 1);
   
   gtk_widget_show(table);
-  
+
+  gtk_widget_set_events(w->window,
+                        GDK_POINTER_MOTION_MASK);
+    
   gtk_widget_set_events(w->socket,
                         GDK_KEY_PRESS_MASK |
-                        GDK_BUTTON_PRESS_MASK);
+                        GDK_BUTTON_PRESS_MASK );
   
   //  gtk_window_set_focus_on_map(w->window, 0);
   
@@ -644,6 +657,10 @@ static void window_init(visualizer_t * v,
   g_signal_connect(G_OBJECT(w->socket), "key-press-event",
                    G_CALLBACK(key_callback),
                    v);
+
+  g_signal_connect(G_OBJECT(w->window), "motion-notify-event",
+                   G_CALLBACK(window_motion_callback),
+                   v);
   
   gtk_widget_show(w->socket);
   
