@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -276,6 +276,14 @@ bg_cfg_section_t * bg_cfg_section_copy(const bg_cfg_section_t * src);
 
 void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst);
 
+/** \ingroup cfg_section
+ *  \brief Like \ref bg_cfg_section_transfer but acts only on the subsections
+ *  \param src Source section
+ *  \param dst Destination section
+ */
+
+void bg_cfg_section_transfer_children(bg_cfg_section_t * src, bg_cfg_section_t * dst);
+
 /** \ingroup cfg_section
  *  \brief Insert a reference to a section as child
  *  \param src s
@@ -533,4 +541,14 @@ void bg_cfg_section_get(bg_cfg_section_t * section,
 int bg_cfg_section_has_subsection(bg_cfg_section_t * section,
                                   const char * name);
 
+/** \ingroup cfg_section
+ *  \brief Restore default values of a section
+ *  \param section The configuration section
+ *  \param info Parameter info
+ */ 
+
+void bg_cfg_section_restore_defaults(bg_cfg_section_t * s,
+                                     const bg_parameter_info_t * info);
+
+
 #endif /* __BG_CFG_REGISTRY_H_ */
