@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -120,6 +120,9 @@ typedef union
  *  \brief Typedef for parmeter description
  */
 
+#define BG_PARAMETER_GLOBAL_PRESET (1<<5) //!< For parameters of the type BG_PARAMETER_SECTION: There should be one preset for all following sections
+
+
 typedef struct bg_parameter_info_s bg_parameter_info_t;
 
 /** \ingroup parameter
@@ -166,7 +169,9 @@ struct bg_parameter_info_s
   int num_digits; //!< Number of digits for floating point parameters
   
   char * help_string; //!< Help strings for tooltips or --help option 
-  
+
+  char * preset_path; //!< Path for storing configuration presets
+
   char ** multi_names_nc; //!< When allocating dynamically, use this instead of multi_names and call \ref bg_parameter_info_set_const_ptrs at the end
 
   char ** multi_labels_nc; //!< When allocating dynamically, use this instead of multi_labels and call \ref bg_parameter_info_set_const_ptrs at the end
