@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -23,6 +23,7 @@
 #define __BG_PLUGIN_H_
 
 #include <gavl/gavl.h>
+#include <gavl/compression.h>
 #include <gmerlin/parameter.h>
 #include <gmerlin/streaminfo.h>
 #include <gmerlin/accelerator.h>
@@ -71,7 +72,8 @@
  *  input pluigns, recorders and filters to enable arbitrary chaining.
  */
 
-typedef int (*bg_read_audio_func_t)(void * priv, gavl_audio_frame_t* frame, int stream,
+typedef int (*bg_read_audio_func_t)(void * priv, gavl_audio_frame_t* frame,
+                                    int stream,
                                     int num_samples);
 
 /** \ingroup plugin
@@ -85,7 +87,8 @@ typedef int (*bg_read_audio_func_t)(void * priv, gavl_audio_frame_t* frame, int
  *  input pluigns, recorders and filters to enable arbitrary chaining.
  */
 
-typedef int (*bg_read_video_func_t)(void * priv, gavl_video_frame_t* frame, int stream);
+typedef int (*bg_read_video_func_t)(void * priv, gavl_video_frame_t* frame,
+                                    int stream);
 
 /** \defgroup plugin_flags Plugin flags
  *  \ingroup plugin
@@ -120,7 +123,7 @@ typedef int (*bg_read_video_func_t)(void * priv, gavl_video_frame_t* frame, int
 /** @}
  */
 
-#define BG_PLUGIN_API_VERSION 23
+#define BG_PLUGIN_API_VERSION 24
 
 /* Include this into all plugin modules exactly once
    to let the plugin loader obtain the API version */
@@ -148,16 +151,7 @@ typedef enum
   {
     BG_STREAM_ACTION_OFF = 0, //!< Stream is switched off and will be ignored
     BG_STREAM_ACTION_DECODE,  //!< Stream is switched on and will be decoded
-    
-    /*
-     */
-    
-    /*
-     *  Future support for compressed frames
-     *  must go here
-     */
-
-    /* BG_STREAM_ACTION_READRAW */
+    BG_STREAM_ACTION_READRAW, //!< Stream will be read in compressed form
     
   } bg_stream_action_t;
 
@@ -578,7 +572,33 @@ struct bg_input_plugin_s
    */
   
   int (*set_track)(void * priv, int track);
-    
+
+  /** \brief Get the compression info of an audio stream
+   *  \param priv The handle returned by the create() method
+   *  \param stream Stream index starting with 0
+   *  \param info Returns the compression info
+   *  \returns 1 if the compression info was returned, 0 if the stream cannot be output in compressed form
+   *
+   *  The returned compression info should be freed with
+   *  \ref gavl_compression_info_free
+   */
+
+  int (*get_audio_compression_info)(void * priv, int stream,
+                                    gavl_compression_info_t * info);
+
+  /** \brief Get the compression info of a video stream
+   *  \param priv The handle returned by the create() method
+   *  \param stream Stream index starting with 0
+   *  \param info Returns the compression info
+   *  \returns 1 if the compression info was returned, 0 if the stream cannot be output in compressed form
+   *
+   *  The returned compression info should be freed with
+   *  \ref gavl_compression_info_free
+   */
+
+  int (*get_video_compression_info)(void * priv, int stream,
+                                    gavl_compression_info_t * info);
+  
   /*
    *  These functions set the audio- video- and subpicture streams
    *  as well as programs (== DVD Angles). All these start with 0
@@ -677,6 +697,31 @@ struct bg_input_plugin_s
   
   bg_read_video_func_t read_video;
 
+  /** \brief Read compressed audio packet
+   *  \param priv The handle returned by the create() method
+   *  \param stream Stream index (starting with 0)
+   *  \param p Returns the packet
+   *  \returns 1 if a packet was read, 0 else
+   *
+   *  You can pass the same packet multiple times to a read fuction.
+   *  Use \ref gavl_packet_free when it's no longer used.
+   */
+
+  int (*read_audio_packet)(void * priv, int stream, gavl_packet_t * p);
+
+  /** \brief Read compressed video packet
+   *  \param priv The handle returned by the create() method
+   *  \param stream Stream index (starting with 0)
+   *  \param p Returns the packet
+   *  \returns 1 if a packet was read, 0 else
+   *
+   *  You can pass the same packet multiple times to a read fuction.
+   *  Use \ref gavl_packet_free when it's no longer used.
+   */
+
+  int (*read_video_packet)(void * priv, int stream, gavl_packet_t * p);
+
+  
   /** \brief Skip frames in a video stream
       \param stream Stream index (starting with 0)
       \param time The time to skip to (will be changed to the true time)
@@ -1329,6 +1374,32 @@ struct bg_encoder_plugin_s
    */
   
   void (*set_callbacks)(void * priv, bg_encoder_callbacks_t * cb);
+
+  /** \brief Query for writing compressed audio packets
+   *  \param priv The handle returned by the create() method
+   *  \param format Format of the source
+   *  \param info Compression info
+   *  \returns 1 if stream compressed format can be written, 0 else
+   *  
+   *  Call this function after all global parameters are set.
+   */
+  
+  int (*writes_compressed_audio)(void * priv,
+                                 const gavl_audio_format_t * format,
+                                 const gavl_compression_info_t * info);
+  
+  /** \brief Query for writing compressed video packets
+   *  \param priv The handle returned by the create() method
+   *  \param format Format of the source
+   *  \param info Compression info
+   *  \returns 1 if stream compressed format can be written, 0 else
+   *  
+   *  Call this function after all global parameters are set.
+   */
+  
+  int (*writes_compressed_video)(void * priv,
+                                 const gavl_video_format_t * format,
+                                 const gavl_compression_info_t * info);
   
   /** \brief Open a file
    *  \param priv The handle returned by the create() method
@@ -1344,16 +1415,6 @@ struct bg_encoder_plugin_s
               const bg_metadata_t * metadata,
               const bg_chapter_list_t * chapter_list);
   
-  /** \brief Return the filename, which can be passed to the player
-   *  \param priv The handle returned by the create() method
-   *
-   *  This must be implemented only if the plugin creates
-   *  files with names different from the the filename passed to
-   *  the open() function
-   */
-  
-  const char * (*get_filename)(void*);
-
   /* Return per stream parameters */
 
   /** \brief Get audio related parameters
@@ -1411,6 +1472,22 @@ struct bg_encoder_plugin_s
   int (*add_audio_stream)(void * priv, const char * language,
                           const gavl_audio_format_t * format);
 
+  /** \brief Add an audio stream fpr compressed writing
+   *  \param priv The handle returned by the create() method
+   *  \param language as ISO 639-2 code (3 characters+'\\0') or NULL
+   *  \param format Format of the source
+   *  \param info Compression info of the source
+   *  \returns Index of this stream (starting with 0)
+   *  
+   *  The format might be changed to the nearest format supported by
+   *  the plugin. Use \ref get_audio_format to get the actual format
+   *  needed by the plugin, after \ref start() was called.
+   */
+  
+  int (*add_audio_stream_compressed)(void * priv, const char * language,
+                                     const gavl_audio_format_t * format,
+                                     const gavl_compression_info_t * info);
+  
   /** \brief Add a video stream
    *  \param priv The handle returned by the create() method
    *  \param format Format of the source
@@ -1423,6 +1500,21 @@ struct bg_encoder_plugin_s
   
   int (*add_video_stream)(void * priv, const gavl_video_format_t * format);
 
+  /** \brief Add a video stream for compressed writing
+   *  \param priv The handle returned by the create() method
+   *  \param format Format of the source
+   *  \param info Compression info of the source
+   *  \returns Index of this stream (starting with 0)
+   *  
+   *  The format might be changed to the nearest format supported by
+   *  the plugin. Use \ref get_video_format to get the actual format
+   *  needed by the plugin, after \ref start() was called.
+   */
+  
+  int (*add_video_stream_compressed)(void * priv,
+                                     const gavl_video_format_t * format,
+                                     const gavl_compression_info_t * info);
+  
   /** \brief Add a text subtitle stream
    *  \param priv The handle returned by the create() method
    *  \param language as ISO 639-2 code (3 characters+'\\0') or NULL
@@ -1574,8 +1666,21 @@ struct bg_encoder_plugin_s
    *  the frame.
    */
   
-  int (*write_audio_frame)(void * data,gavl_audio_frame_t * frame, int stream);
+  int (*write_audio_frame)(void * data, gavl_audio_frame_t * frame, int stream);
 
+  /** \brief Write audio packet
+   *  \param priv The handle returned by the create() method
+   *  \param packet Packet with compressed data
+   *  \param stream Stream index (starting with 0)
+   *  \returns 1 is the data was successfully written, 0 else
+   *
+   *  The actual number of samples must be stored in the duration member of
+   *  the packet.
+   */
+  
+  int (*write_audio_packet)(void * data, gavl_packet_t * packet, int stream);
+
+  
   /** \brief Write video frame
    *  \param priv The handle returned by the create() method
    *  \param frame Frame
@@ -1583,8 +1688,17 @@ struct bg_encoder_plugin_s
    *  \returns 1 is the data was successfully written, 0 else
    */
 
-  int (*write_video_frame)(void * data,gavl_video_frame_t * frame, int stream);
+  int (*write_video_frame)(void * data, gavl_video_frame_t * frame, int stream);
 
+  /** \brief Write video packet
+   *  \param priv The handle returned by the create() method
+   *  \param packet Packet with compressed data
+   *  \param stream Stream index (starting with 0)
+   *  \returns 1 is the data was successfully written, 0 else
+   */
+  
+  int (*write_video_packet)(void * data, gavl_packet_t * packet, int stream);
+  
   /** \brief Write a text subtitle
    *  \param priv The handle returned by the create() method
    *  \param frame The text
@@ -1775,16 +1889,21 @@ struct bg_image_reader_plugin_s
   
   int (*read_header)(void * priv, const char * filename,
                      gavl_video_format_t * format);
-  
-  const bg_metadata_t * (*get_metadata)(void * priv);
-  
-  /** \brief Get file infos
+
+  /** \brief Get metadata
    *  \param priv The handle returned by the create() method
-   *  \returns 
+   *  \returns Metadata for the image or NULL
    */
   
+  const bg_metadata_t * (*get_metadata)(void * priv);
+
+  /** \brief Get compression info
+   *  \param priv The handle returned by the create() method
+   *  \param ci Returns the compression info
+   *  \returns 1 if the compression info could be returned, 0 else
+   */
   
-  char ** (*get_info)(void * priv);
+  int (*get_compression_info)(void * priv, gavl_compression_info_t * ci);
   
   /** \brief Read the image
    *  \param priv The handle returned by the create() method
