@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -54,8 +54,7 @@ typedef struct
   int saved_timeout;
   int64_t last_ping_time;
 
-  KeyCode fake_keycode; /* Which key to press */
-  int was_pressed;
+  int fake_motion;
   
   gavl_timer_t * timer;
 
