@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -145,7 +145,7 @@ static VisUIWidget * check_widget(VisUIWidget * w, const char * name,
     case VISUAL_WIDGET_TYPE_BOX:         /**< Box widget: \a VisUIBox. */
       /* Get children */
       list_entry = (VisListEntry*)0;
-      while(visual_list_next(&(VISUAL_UI_BOX(w)->childs), &list_entry))
+      while(visual_list_next(&VISUAL_UI_BOX(w)->childs, &list_entry))
         {
         if((ret = check_widget(list_entry->data, name, info)))
           return ret;
@@ -154,7 +154,7 @@ static VisUIWidget * check_widget(VisUIWidget * w, const char * name,
     case VISUAL_WIDGET_TYPE_TABLE:       /**< Table widget: \a VisUITable. */
       /* Get children */
       list_entry = (VisListEntry*)0;
-      while(visual_list_next(&(VISUAL_UI_TABLE(w)->childs), &list_entry))
+      while(visual_list_next(&VISUAL_UI_TABLE(w)->childs, &list_entry))
         {
         if((ret = check_widget(((VisUITableEntry*)list_entry->data)->widget, name, info)))
           {
@@ -166,7 +166,7 @@ static VisUIWidget * check_widget(VisUIWidget * w, const char * name,
       /* Get children */
       /* Get children */
       list_entry = (VisListEntry*)0;
-      while(visual_list_next(&(VISUAL_UI_NOTEBOOK(w)->childs), &list_entry))
+      while(visual_list_next(&VISUAL_UI_NOTEBOOK(w)->childs, &list_entry))
         {
         if((ret = check_widget(list_entry->data, name, info)))
           return ret;
@@ -242,13 +242,13 @@ static VisUIWidget * check_widget(VisUIWidget * w, const char * name,
       info->flags |= BG_PARAMETER_SYNC;
       num_items = 0;
       list_entry = (VisListEntry*)0;
-      while(visual_list_next(&(VISUAL_UI_CHOICE(w)->choices.choices), &list_entry))
+      while(visual_list_next(&VISUAL_UI_CHOICE(w)->choices.choices, &list_entry))
         num_items++;
       info->multi_names_nc = calloc(num_items+1, sizeof(info->multi_names_nc));
       list_entry = (VisListEntry*)0;
       for(i = 0; i < num_items; i++)
         {
-        visual_list_next(&(VISUAL_UI_CHOICE(w)->choices.choices), &list_entry);
+        visual_list_next(&VISUAL_UI_CHOICE(w)->choices.choices, &list_entry);
         info->multi_names_nc[i] = bg_strdup((char*)0, ((VisUIChoiceEntry*)(list_entry->data))->name);
 
         /* Check if this is the current value */
@@ -487,8 +487,12 @@ bg_plugin_info_t * bg_lv_get_info(const char * filename)
     bg_x11_window_set_size(win, 640, 480);
     
     bg_x11_window_realize(win);
-    bg_x11_window_start_gl(win);
-    bg_x11_window_set_gl(win);
+    if(!bg_x11_window_start_gl(win))
+      {
+      ret->flags |=  BG_PLUGIN_UNSUPPORTED;
+      }
+    else
+      bg_x11_window_set_gl(win);
     }
   else
     {
@@ -498,11 +502,15 @@ bg_plugin_info_t * bg_lv_get_info(const char * filename)
   ret->priority = 1;
 
   /* Must realize the actor to get the parameters */
-  visual_actor_realize(actor);
+
+  if(!(ret->flags & BG_PLUGIN_UNSUPPORTED))
+    {
+    visual_actor_realize(actor);
+    ret->parameters =
+      create_parameters(actor, (VisUIWidget***)0, (VisParamEntry***)0);
+    visual_object_unref(VISUAL_OBJECT(actor));
+    }
   
-  ret->parameters = create_parameters(actor, (VisUIWidget***)0, (VisParamEntry***)0);
-  
-  visual_object_unref(VISUAL_OBJECT(actor));
   
   if(win)
     {
@@ -751,7 +759,7 @@ static void set_parameter_lv(void * data, const char * name,
     /* Get the selected index */
     supported = 0;
     list_entry = (VisListEntry*)0;
-    while(visual_list_next(&(VISUAL_UI_CHOICE(priv->widgets[index])->choices.choices),
+    while(visual_list_next(&VISUAL_UI_CHOICE(priv->widgets[index])->choices.choices,
                            &list_entry))
       {
       if(!strcmp(((VisUIChoiceEntry*)(list_entry->data))->name, val->val_str))
