@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -198,7 +198,7 @@ void bg_cfg_item_transfer(bg_cfg_item_t * src, bg_cfg_item_t * dst)
   {
   bg_parameter_info_t info;
   bg_cfg_item_to_parameter(src, &info);
-  bg_parameter_value_copy(&(dst->value), &(src->value), &info);
+  bg_parameter_value_copy(&dst->value, &src->value, &info);
   }
 
 bg_cfg_item_t * bg_cfg_item_copy(bg_cfg_item_t * src)
