@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -207,11 +207,6 @@ int bg_cfg_section_has_subsection(bg_cfg_section_t * s,
   return 0;
   }
 
-
-/*
- *  Get/Set values
- */
-
 bg_cfg_item_t * bg_cfg_section_find_item(bg_cfg_section_t * section,
                                          const bg_parameter_info_t * info)
   {
@@ -237,21 +232,28 @@ bg_cfg_item_t * bg_cfg_section_find_item(bg_cfg_section_t * section,
   return prev->next;
   }
 
-
-void bg_cfg_section_set_parameter(bg_cfg_section_t * section,
-                                  const bg_parameter_info_t * info,
-                                  const bg_parameter_value_t * value)
+static bg_cfg_item_t * find_item_nocreate(bg_cfg_section_t * section,
+                                          const bg_parameter_info_t * info)
   {
-  bg_cfg_item_t * item;
+  bg_cfg_item_t * ret;
+  ret = section->items;
+  while(ret)
+    {
+    if(!strcmp(ret->name, info->name))
+      return ret;
+    ret = ret->next;
+    }
+  return NULL;
+  }
 
-  if(!value)
-    return;
 
-  item = bg_cfg_section_find_item(section, info);
+/*
+ *  Get/Set values
+ */
 
-  if(!item)
-    return;
-  
+static void value_2_item(const bg_parameter_value_t * value,
+                         bg_cfg_item_t * item)
+  {
   switch(item->type)
     {
     case BG_CFG_INT:
@@ -280,7 +282,23 @@ void bg_cfg_section_set_parameter(bg_cfg_section_t * section,
       break;
       
     }
+  }
   
+void bg_cfg_section_set_parameter(bg_cfg_section_t * section,
+                                  const bg_parameter_info_t * info,
+                                  const bg_parameter_value_t * value)
+  {
+  bg_cfg_item_t * item;
+
+  if(!value)
+    return;
+
+  item = bg_cfg_section_find_item(section, info);
+
+  if(!item)
+    return;
+  
+  value_2_item(value, item);
   }
 
 static char * parse_string(const char * str, int * len_ret)
@@ -438,7 +456,7 @@ int bg_cfg_section_set_parameters_from_string(bg_cfg_section_t * section,
         end_c = str;
         if(*end_c == '{')
           end_c++;
-        end_c += gavl_time_parse(end_c, &(item->value.val_time));
+        end_c += gavl_time_parse(end_c, &item->value.val_time);
         if(*end_c == '}')
           end_c++;
         str = end_c;
@@ -751,7 +769,7 @@ static void do_apply(bg_cfg_section_t * section,
 
   while(infos[num].name)
     {
-    item = bg_cfg_section_find_item(section, &(infos[num]));
+    item = bg_cfg_section_find_item(section, &infos[num]);
 
     if(!item)
       {
@@ -761,11 +779,11 @@ static void do_apply(bg_cfg_section_t * section,
     if(prefix)
       {
       tmp_string = bg_sprintf("%s.%s", prefix, item->name);
-      func(callback_data, tmp_string, &(item->value));
+      func(callback_data, tmp_string, &item->value);
       free(tmp_string);
       }
     else
-      func(callback_data, item->name, &(item->value));
+      func(callback_data, item->name, &item->value);
 
     /* If this was a menu, apply children */ 
 
@@ -901,9 +919,9 @@ void bg_cfg_section_get(bg_cfg_section_t * section,
 
   while(infos[num].name)
     {
-    item = bg_cfg_section_find_item(section, &(infos[num]));
+    item = bg_cfg_section_find_item(section, &infos[num]);
     if(item)
-      func(callback_data, item->name, &(item->value));
+      func(callback_data, item->name, &item->value);
     num++;
     }
   }
@@ -1117,26 +1135,10 @@ bg_cfg_section_t * bg_cfg_section_copy(const bg_cfg_section_t * src)
   return ret;
   }
 
-void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst)
+void bg_cfg_section_transfer_children(bg_cfg_section_t * src, bg_cfg_section_t * dst)
   {
-  bg_cfg_item_t * src_item;
-  
   bg_cfg_section_t * src_child;
   bg_cfg_section_t * dst_child;
-  bg_parameter_info_t  info;
-  /* Copy items */
-  
-  src_item = src->items;
-  
-  while(src_item)
-    {
-    bg_cfg_item_to_parameter(src_item, &info);
-    bg_cfg_section_set_parameter(dst, &info, &(src_item->value));
-    src_item = src_item->next;
-    }
-  
-  /* Copy children */
-  
   src_child = src->children;
   
   while(src_child)
@@ -1145,6 +1147,27 @@ void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst)
     bg_cfg_section_transfer(src_child, dst_child);
     src_child = src_child->next;
     }
+  
+  }
+
+void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst)
+  {
+  bg_cfg_item_t * src_item;
+  bg_parameter_info_t  info;
+  /* Copy items */
+  
+  src_item = src->items;
+  
+  while(src_item)
+    {
+    bg_cfg_item_to_parameter(src_item, &info);
+    bg_cfg_section_set_parameter(dst, &info, &src_item->value);
+    src_item = src_item->next;
+    }
+  
+  /* Copy children */
+  
+  bg_cfg_section_transfer_children(src, dst);
   }
 
 
@@ -1200,6 +1223,9 @@ static void create_items(bg_cfg_section_t * section,
 
   i = 0;
 
+  //  if(section->name && !strcmp(section->name, "e_mpeg"))
+  //    fprintf(stderr, "e_mpeg\n");
+  
   while(info[i].name)
     {
     if((info[i].type == BG_PARAMETER_SECTION) &&
@@ -1227,7 +1253,7 @@ static void create_items(bg_cfg_section_t * section,
       //      fprintf(stderr, "Section: %s, parameter: %s\n",
       //            section->name, info[i].name);
       
-      bg_cfg_section_find_item(section, &(info[i]));
+      bg_cfg_section_find_item(section, &info[i]);
     
       if(info[i].multi_parameters)
         {
@@ -1306,3 +1332,52 @@ void bg_cfg_section_add_ref(bg_cfg_section_t * s, bg_cfg_section_t * ref)
   s->refs[s->num_refs] = ref;
   s->num_refs++;
   }
+
+void bg_cfg_section_restore_defaults(bg_cfg_section_t * s,
+                                     const bg_parameter_info_t * info)
+  {
+  bg_cfg_item_t * item;
+  int i;
+  bg_cfg_section_t * subsection;
+  bg_cfg_section_t * subsubsection;
+  
+  while(info->name)
+    {
+    if(info->flags & BG_PARAMETER_HIDE_DIALOG)
+      {
+      info++;
+      continue;
+      }
+    item = find_item_nocreate(s, info);
+
+    if(!item)
+      {
+      info++;
+      continue;
+      }
+    
+    value_2_item(&info->val_default, item);
+    
+    if(info->multi_parameters && bg_cfg_section_has_subsection(s, info->name))
+      {
+      subsection = bg_cfg_section_find_subsection(s, info->name);
+      i = 0;
+      
+      while(info->multi_names[i])
+        {
+        if(info->multi_parameters[i] &&
+           bg_cfg_section_has_subsection(subsection, info->multi_names[i]))
+          {
+          subsubsection =
+            bg_cfg_section_find_subsection(subsection, info->multi_names[i]);
+          bg_cfg_section_restore_defaults(subsubsection,
+                                          info->multi_parameters[i]);
+          }
+        i++;
+        }
+      }
+    
+    info++;
+    }
+  
+  }
