@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -44,6 +44,8 @@ typedef struct
   const bg_parameter_info_t * parameters;
 
   char language[4];
+
+  const gavl_compression_info_t * ci;
   
   } audio_stream_t;
 
@@ -65,6 +67,7 @@ typedef struct
   char * stats_file;
   
   //  int64_t last_timestamp;
+  const gavl_compression_info_t * ci;
   
   } video_stream_t;
 
@@ -537,21 +540,26 @@ static int start_audio(bg_encoder_t * enc, int stream)
   s->priv = h->priv;
 
   /* Add stream */
-  
-  s->out_index = s->plugin->add_audio_stream(s->priv, s->language, &s->format);
-  
-  /* Apply parameters */ 
 
-  if(s->plugin->set_audio_parameter)
+  if(s->ci)
+    s->out_index = s->plugin->add_audio_stream_compressed(s->priv, s->language, &s->format, s->ci);
+  else
     {
-    st.func =  s->plugin->set_audio_parameter;
-    st.data =  s->priv;
-    st.index = s->out_index;
+    s->out_index = s->plugin->add_audio_stream(s->priv, s->language, &s->format);
+  
+    /* Apply parameters */ 
+
+    if(s->plugin->set_audio_parameter)
+      {
+      st.func =  s->plugin->set_audio_parameter;
+      st.data =  s->priv;
+      st.index = s->out_index;
     
-    bg_cfg_section_apply(s->section,
-                         s->parameters,
-                         set_stream_param,
-                         &st);
+      bg_cfg_section_apply(s->section,
+                           s->parameters,
+                           set_stream_param,
+                           &st);
+      }
     }
   
   return 1;
@@ -576,32 +584,37 @@ static int start_video(bg_encoder_t * enc, int stream)
 
   /* Add stream */
   
-  s->out_index = s->plugin->add_video_stream(s->priv, &s->format);
+  if(s->ci)
+    s->out_index = s->plugin->add_video_stream_compressed(s->priv, &s->format, s->ci);
+  else
+    {
+    s->out_index = s->plugin->add_video_stream(s->priv, &s->format);
   
-  /* Apply parameters */ 
-  if(s->plugin->set_video_parameter)
-    {
-    st.func =  s->plugin->set_video_parameter;
-    st.data =  s->priv;
-    st.index = s->out_index;
-    
-    bg_cfg_section_apply(s->section,
-                         s->parameters,
-                         set_stream_param,
-                         &st);
-    }
-
-  /* Set pass */
-
-  if(s->total_passes)
-    {
-    if(!s->plugin->set_video_pass ||
-       !s->plugin->set_video_pass(s->priv, s->out_index, s->pass, s->total_passes,
-                                  s->stats_file))
+    /* Apply parameters */ 
+    if(s->plugin->set_video_parameter)
       {
-      bg_log(BG_LOG_ERROR, LOG_DOMAIN,
-             "Multipass encoding not supported by encoder plugin");
-      return 0;
+      st.func =  s->plugin->set_video_parameter;
+      st.data =  s->priv;
+      st.index = s->out_index;
+      
+      bg_cfg_section_apply(s->section,
+                           s->parameters,
+                           set_stream_param,
+                           &st);
+      }
+    
+    /* Set pass */
+    
+    if(s->total_passes)
+      {
+      if(!s->plugin->set_video_pass ||
+         !s->plugin->set_video_pass(s->priv, s->out_index, s->pass, s->total_passes,
+                                    s->stats_file))
+        {
+        bg_log(BG_LOG_ERROR, LOG_DOMAIN,
+               "Multipass encoding not supported by encoder plugin");
+        return 0;
+        }
       }
     }
   
@@ -748,7 +761,7 @@ int bg_encoder_start(bg_encoder_t * enc)
 /* Add streams */
 int bg_encoder_add_audio_stream(bg_encoder_t * enc,
                                 const char * language,
-                                gavl_audio_format_t * format,
+                                const gavl_audio_format_t * format,
                                 int source_index)
   {
   int ret;
@@ -779,7 +792,7 @@ int bg_encoder_add_audio_stream(bg_encoder_t * enc,
   }
 
 int bg_encoder_add_video_stream(bg_encoder_t * enc,
-                                gavl_video_format_t * format,
+                                const gavl_video_format_t * format,
                                 int source_index)
   {
   int ret;
@@ -803,6 +816,53 @@ int bg_encoder_add_video_stream(bg_encoder_t * enc,
   return ret;
   }
 
+int bg_encoder_add_audio_stream_compressed(bg_encoder_t * enc, const char * language,
+                                           const gavl_audio_format_t * format,
+                                           const gavl_compression_info_t * info,
+                                           int source_index)
+  {
+  int ret;
+  audio_stream_t * s;
+    
+  REALLOC_STREAM(enc->audio_streams,
+                 enc->num_audio_streams);
+
+  gavl_audio_format_copy(&s->format, format);
+  s->in_index = source_index;
+  
+  s->ci = info;
+  
+  if(language)
+    strncpy(s->language, language, 3);
+  
+  ret = enc->num_audio_streams;
+  enc->num_audio_streams++;
+  return ret;
+  
+  }
+
+int bg_encoder_add_video_stream_compressed(bg_encoder_t * enc,
+                                           const gavl_video_format_t * format,
+                                           const gavl_compression_info_t * info,
+                                           int source_index)
+  {
+  int ret;
+  video_stream_t * s;
+
+  REALLOC_STREAM(enc->video_streams,
+                 enc->num_video_streams);
+
+  gavl_video_format_copy(&s->format, format);
+  s->in_index = source_index;
+  
+  s->ci = info;
+  
+  ret = enc->num_video_streams;
+  enc->num_video_streams++;
+  return ret;
+  }
+
+
 int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
                                         const char * language,
                                         int timescale,
@@ -838,7 +898,7 @@ int bg_encoder_add_subtitle_text_stream(bg_encoder_t * enc,
 
 int bg_encoder_add_subtitle_overlay_stream(bg_encoder_t * enc,
                                            const char * language,
-                                           gavl_video_format_t * format,
+                                           const gavl_video_format_t * format,
                                            int source_index, bg_stream_type_t source_format)
   {
   int ret;
@@ -965,3 +1025,101 @@ int bg_encoder_write_subtitle_overlay(bg_encoder_t * enc,
   subtitle_overlay_stream_t * s = &enc->subtitle_overlay_streams[stream];
   return s->plugin->write_subtitle_overlay(s->priv, ovl, s->out_index);
   }
+
+static bg_plugin_handle_t *
+open_dummy_encoder(bg_encoder_t * enc,
+                   const bg_plugin_info_t * plugin_info,
+                   bg_cfg_section_t * plugin_section)
+  {
+  bg_encoder_plugin_t * plugin;
+  bg_plugin_handle_t * ret;
+  ret = bg_plugin_load(enc->plugin_reg, plugin_info);
+  
+  plugin = (bg_encoder_plugin_t *)ret->plugin;
+
+  
+  if(plugin->common.set_parameter)
+    bg_cfg_section_apply(plugin_section,
+                         plugin_info->parameters,
+                         plugin->common.set_parameter,
+                         ret->priv);
+  return ret;
+  }
+
+int bg_encoder_writes_compressed_audio(bg_encoder_t * enc,
+                                       const gavl_audio_format_t * format,
+                                       const gavl_compression_info_t * info)
+  {
+  int ret;
+  bg_encoder_plugin_t * plugin;
+  const bg_plugin_info_t * plugin_info;
+  bg_plugin_handle_t * h;
+  bg_cfg_section_t * plugin_section;
+  
+  if(enc->audio_plugin.info)
+    {
+    plugin_info = enc->audio_plugin.info;
+    plugin_section = enc->audio_plugin.section;
+    }
+  else if(enc->video_plugin.info)
+    {
+    plugin_info = enc->video_plugin.info;
+    plugin_section = enc->video_plugin.section;
+    }
+  else
+    return 0;
+  
+  h = open_dummy_encoder(enc, plugin_info, plugin_section);
+  plugin = (bg_encoder_plugin_t *)h->plugin;
+
+  if(plugin->writes_compressed_audio)
+    ret = plugin->writes_compressed_audio(h->priv,
+                                          format, info);
+  else
+    ret = 0;
+  bg_plugin_unref(h);
+  return ret;
+  }
+
+int bg_encoder_writes_compressed_video(bg_encoder_t * enc,
+                                       const gavl_video_format_t * format,
+                                       const gavl_compression_info_t * info)
+  {
+  int ret;
+  bg_encoder_plugin_t * plugin;
+  const bg_plugin_info_t * plugin_info;
+  bg_plugin_handle_t * h;
+  bg_cfg_section_t * plugin_section;
+
+  if(enc->video_plugin.info)
+    {
+    plugin_info = enc->video_plugin.info;
+    plugin_section = enc->video_plugin.section;
+    }
+  else
+    return 0;
+  
+  h = open_dummy_encoder(enc, plugin_info, plugin_section);
+  plugin = (bg_encoder_plugin_t *)h->plugin;
+  
+  if(plugin->writes_compressed_video)
+    ret = plugin->writes_compressed_video(h->priv,
+                                          format, info);
+  else
+    ret = 0;
+  bg_plugin_unref(h);
+  return ret;
+  }
+
+    
+int bg_encoder_write_audio_packet(bg_encoder_t * enc, gavl_packet_t * p, int stream)
+  {
+  audio_stream_t * s = &enc->audio_streams[stream];
+  return s->plugin->write_audio_packet(s->priv, p, s->out_index);
+  }
+
+int bg_encoder_write_video_packet(bg_encoder_t * enc, gavl_packet_t * p, int stream)
+  {
+  video_stream_t * s = &enc->video_streams[stream];
+  return s->plugin->write_video_packet(s->priv, p, s->out_index);
+  }
