@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -26,6 +26,7 @@
 #include <string.h>
 #include "gtk_dialog.h"
 #include <gui_gtk/gtkutils.h>
+#include <gui_gtk/presetmenu.h>
 
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "cfg_dialog"
@@ -50,15 +51,20 @@ typedef struct dialog_section_s
 
   const bg_parameter_info_t * infos;
   bg_cfg_section_t * cfg_section;
-
+  
   /* Dialog sections can be nested */
-  struct dialog_section_s * children;
+  struct dialog_section_s ** children;
   int num_children;
     
   struct dialog_section_s * parent;
   
   /* Index in global notebook */
   int notebook_index;
+
+  bg_gtk_preset_menu_t * preset_menu;
+  bg_cfg_section_t * preset_section;
+
+  int private_cfg_section;
   } dialog_section_t;
 
 struct bg_dialog_s
@@ -68,6 +74,8 @@ struct bg_dialog_s
   GtkWidget * close_button;
   GtkWidget * window;
   GtkWidget * mainbox;
+  GtkWidget * action_box;
+  
   dialog_section_t root_section;
   int visible;
 
@@ -79,6 +87,8 @@ struct bg_dialog_s
   int result;
   
   bg_plugin_registry_t * plugin_reg;
+  bg_gtk_preset_menu_t * preset_menu;
+  bg_cfg_section_t     * preset_section;
   };
 
 static int parent_index(dialog_section_t * s)
@@ -90,7 +100,7 @@ static int parent_index(dialog_section_t * s)
 
   for(i = 0; i < s->parent->num_children; i++)
     {
-    if(&(s->parent->children[i]) == s)
+    if(s->parent->children[i] == s)
       return i;
     }
   return -1;
@@ -168,13 +178,13 @@ static dialog_section_t * iter_2_section(bg_dialog_t * d,
 
   indices = gtk_tree_path_get_indices(path);
 
-  ret = &d->root_section.children[indices[0]];
+  ret = d->root_section.children[indices[0]];
 
   depth = gtk_tree_path_get_depth(path);
   
   for(i = 1; i < depth; i++)
     {
-    ret = &(ret->children[indices[i]]);
+    ret = ret->children[indices[i]];
     }
   
   gtk_tree_path_free(path);
@@ -197,14 +207,14 @@ static void reset_section(dialog_section_t * s)
     bg_parameter_value_copy(&s->widgets[i].value, &s->widgets[i].last_value,
                             s->widgets[i].info);
 
-    s->widgets[i].funcs->get_value(&(s->widgets[i]));
+    s->widgets[i].funcs->get_value(&s->widgets[i]);
     
     if(s->cfg_section)
       {
       if(s->widgets[i].info->flags & BG_PARAMETER_SYNC)
         bg_cfg_section_set_parameter(s->cfg_section,
                                      s->widgets[i].info,
-                                      &(s->widgets[i].value));
+                                      &s->widgets[i].value);
 
       /* If we have multi parameters, we'll also reset the subsection, even if
          BG_PARAMETER_SYNC isn't set */
@@ -215,7 +225,7 @@ static void reset_section(dialog_section_t * s)
         bg_cfg_section_transfer(s->widgets[i].cfg_subsection_save, cfg_subsection);
         }
       if(s->widgets[i].funcs->apply_sub_params)
-        s->widgets[i].funcs->apply_sub_params(&(s->widgets[i]));
+        s->widgets[i].funcs->apply_sub_params(&s->widgets[i]);
       }
     
     if(s->set_param && (s->widgets[i].info->flags & BG_PARAMETER_SYNC))
@@ -235,7 +245,7 @@ static void reset_section(dialog_section_t * s)
         }
       else
         s->set_param(s->callback_data, s->widgets[i].info->name,
-                     &(s->widgets[i].value));
+                     &s->widgets[i].value);
       }
     }
   
@@ -243,9 +253,68 @@ static void reset_section(dialog_section_t * s)
     s->set_param(s->callback_data, NULL, NULL);
   
   for(i = 0; i < s->num_children; i++)
-    reset_section(&(s->children[i]));
+    reset_section(s->children[i]);
   }
 
+static void restore_section(dialog_section_t * s, bg_cfg_section_t * cfg_section)
+  {
+  int i;
+  bg_parameter_value_t val;
+  char * pos;
+  int set_param = 0;
+
+  if(!cfg_section)
+    return;
+  
+  for(i = 0; i < s->num_widgets; i++)
+    {
+    if(!s->widgets[i].funcs->get_value)
+      continue;
+
+    bg_cfg_section_get_parameter(cfg_section,
+                                 s->widgets[i].info,
+                                 &s->widgets[i].value);
+    
+    s->widgets[i].funcs->get_value(&s->widgets[i]);
+    
+    if(s->set_param && (s->widgets[i].info->flags & BG_PARAMETER_SYNC))
+      {
+      set_param = 1;
+      if((s->widgets[i].info->type == BG_PARAMETER_DEVICE) &&
+         (s->widgets[i].value.val_str) &&
+         strchr(s->widgets[i].value.val_str, ':'))
+        {
+        val.val_str = bg_strdup((char*)0, s->widgets[i].value.val_str);
+        pos = strchr(val.val_str, ':');
+        if(pos)
+          *pos = '\0';
+        s->set_param(s->callback_data, s->widgets[i].info->name,
+                     &val);
+        free(val.val_str);
+        }
+      else
+        s->set_param(s->callback_data, s->widgets[i].info->name,
+                     &s->widgets[i].value);
+      }
+
+    /* Copy subsections */
+
+    if(s->widgets[i].info->multi_parameters)
+      {
+      bg_cfg_section_t * src1, * dst1;
+      dst1 = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
+      src1 = bg_cfg_section_find_subsection(cfg_section, s->widgets[i].info->name);
+      bg_cfg_section_transfer_children(src1, dst1);
+      }
+    }
+  
+  if(set_param)
+    s->set_param(s->callback_data, NULL, NULL);
+  }
+
+
+
+
 static void apply_section(dialog_section_t * s)
   {
   bg_parameter_value_t val;
@@ -258,7 +327,7 @@ static void apply_section(dialog_section_t * s)
     if(!s->widgets[i].funcs->set_value)
       continue;
     
-    s->widgets[i].funcs->set_value(&(s->widgets[i]));
+    s->widgets[i].funcs->set_value(&s->widgets[i]);
     bg_parameter_value_copy(&s->widgets[i].last_value, &s->widgets[i].value,
                             s->widgets[i].info);
     
@@ -266,7 +335,7 @@ static void apply_section(dialog_section_t * s)
       {
       bg_cfg_section_set_parameter(s->cfg_section,
                                    s->widgets[i].info,
-                                   &(s->widgets[i].value));
+                                   &s->widgets[i].value);
       
       }
 
@@ -297,7 +366,7 @@ static void apply_section(dialog_section_t * s)
         }
       else
         s->set_param(s->callback_data, s->widgets[i].info->name,
-                     &(s->widgets[i].value));
+                     &s->widgets[i].value);
       }
     }
 
@@ -306,18 +375,18 @@ static void apply_section(dialog_section_t * s)
     s->set_param(s->callback_data, NULL, NULL);
 
   for(i = 0; i < s->num_children; i++)
-    apply_section(&(s->children[i]));
+    apply_section(s->children[i]);
   
   }
 
 static void apply_values(bg_dialog_t * d)
   {
-  apply_section(&(d->root_section));
+  apply_section(&d->root_section);
   }
 
 static void reset_values(bg_dialog_t * d)
   {
-  reset_section(&(d->root_section));
+  reset_section(&d->root_section);
   }
 
 static void button_callback(GtkWidget * w, gpointer * data)
@@ -398,9 +467,9 @@ static bg_dialog_t * create_dialog(const char * title)
   ret->close_button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
   ret->ok_button    = gtk_button_new_from_stock(GTK_STOCK_OK);
 
-  GTK_WIDGET_SET_FLAGS(ret->apply_button, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS(ret->close_button, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS(ret->ok_button, GTK_CAN_DEFAULT);
+  bg_gtk_widget_set_can_default(ret->apply_button, TRUE);
+  bg_gtk_widget_set_can_default(ret->close_button, TRUE);
+  bg_gtk_widget_set_can_default(ret->ok_button, TRUE);
   
   gtk_window_set_modal(GTK_WINDOW(ret->window), TRUE);
   
@@ -413,9 +482,9 @@ static bg_dialog_t * create_dialog(const char * title)
   g_signal_connect(G_OBJECT(ret->window), "delete_event",
                      G_CALLBACK(delete_callback), (gpointer)ret);
 
-  GTK_WIDGET_SET_FLAGS (ret->close_button, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ret->apply_button, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ret->ok_button, GTK_CAN_DEFAULT);
+  bg_gtk_widget_set_can_default(ret->close_button, TRUE);
+  bg_gtk_widget_set_can_default(ret->apply_button, TRUE);
+  bg_gtk_widget_set_can_default(ret->ok_button, TRUE);
   
   gtk_widget_show(ret->apply_button);
   gtk_widget_show(ret->close_button);
@@ -473,9 +542,12 @@ static bg_dialog_t * create_dialog(const char * title)
   gtk_paned_add1(GTK_PANED(hbox), ret->scrolledwindow);
   gtk_paned_add2(GTK_PANED(hbox), ret->notebook);
   gtk_widget_show(hbox);
+
+  ret->action_box = gtk_hbox_new(FALSE, 0);
   
   ret->mainbox = gtk_vbox_new(0, 5);
   gtk_box_pack_start(GTK_BOX(ret->mainbox), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(ret->mainbox), ret->action_box, FALSE, FALSE, 0);
   
   buttonbox = gtk_hbutton_box_new();
   gtk_box_set_spacing(GTK_BOX(buttonbox), 10);
@@ -493,6 +565,88 @@ static bg_dialog_t * create_dialog(const char * title)
   return ret;
   }
 
+static void restore_button_callback(GtkWidget * w, gpointer data)
+  {
+  dialog_section_t * section = data;
+  bg_cfg_section_t * tmp_section;
+
+  //  fprintf(stderr, "Restore factory defaults %p\n", section);
+
+  tmp_section = bg_cfg_section_copy(section->cfg_section);
+  
+  bg_cfg_section_restore_defaults(tmp_section,
+                                  section->widgets[0].info);
+  
+  restore_section(section, tmp_section);
+  bg_cfg_section_destroy(tmp_section);
+  }
+
+static GtkWidget * create_restore_button(dialog_section_t * section)
+  {
+  GtkWidget * button;
+  GtkWidget * image;
+  char * path;
+  path = bg_search_file_read("icons", "refresh_16.png");
+  if(path)
+    {
+    image = gtk_image_new_from_file(path);
+    free(path);
+    }
+  else
+    image = gtk_image_new();
+
+  gtk_widget_show(image);
+  button = gtk_button_new();
+  gtk_container_add(GTK_CONTAINER(button), image);
+  
+  g_signal_connect(G_OBJECT(button), "clicked",
+                   G_CALLBACK(restore_button_callback), section);
+
+  gtk_widget_show(button);
+
+  bg_gtk_tooltips_set_tip(button, "Restore factory defaults", PACKAGE);
+  
+  return button;
+  }
+
+static void preset_load_callback(void * data)
+  {
+  dialog_section_t * s = data;
+  restore_section(s, s->preset_section);
+  }
+
+static void preset_save_callback(void * data)
+  {
+  int i;
+  dialog_section_t * s = data;
+
+  //  fprintf(stderr, "preset_save_callback %p\n", data);
+  
+  for(i = 0; i < s->num_widgets; i++)
+    {
+    if(!s->widgets[i].funcs->set_value)
+      continue;
+    
+    s->widgets[i].funcs->set_value(&s->widgets[i]);
+    
+    bg_cfg_section_set_parameter(s->preset_section,
+                                 s->widgets[i].info,
+                                 &s->widgets[i].value);
+
+    if(s->widgets[i].info->multi_parameters)
+      {
+      bg_cfg_section_t * src1;
+      bg_cfg_section_t * dst1;
+      
+      src1 = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
+      dst1 = bg_cfg_section_find_subsection(s->preset_section, s->widgets[i].info->name);
+
+      bg_cfg_section_transfer_children(src1, dst1);
+      
+      }
+    }
+  }
+
 static GtkWidget * create_section(dialog_section_t * section,
                                   const bg_parameter_info_t * info,
                                   bg_cfg_section_t * s,
@@ -500,7 +654,8 @@ static GtkWidget * create_section(dialog_section_t * section,
                                   bg_get_parameter_func_t get_param,
                                   void * data,
                                   const char * translation_domain,
-                                  bg_plugin_registry_t * plugin_reg)
+                                  bg_plugin_registry_t * plugin_reg,
+                                  bg_cfg_section_t * preset_section)
   {
   int i, count, j;
   int row, column, num_columns;
@@ -508,10 +663,13 @@ static GtkWidget * create_section(dialog_section_t * section,
   
   GtkWidget * table;
   GtkWidget * label;
+  GtkWidget * action_box;
+  GtkWidget * vbox;
+  GtkWidget * restore_button;
   
   /* If info == NULL, we create a label, which
      tell the user, that there is nothing to do */
-
+  
   if(!info)
     {
     table = gtk_table_new(1, 1, 0);
@@ -522,7 +680,9 @@ static GtkWidget * create_section(dialog_section_t * section,
     gtk_widget_show(table);
     return table;
     }
-  
+
+  //  fprintf(stderr, "create section %p %p %p\n", section, s, preset_section);
+ 
   section->num_widgets = 0;
   i = 0;
 
@@ -581,9 +741,15 @@ static GtkWidget * create_section(dialog_section_t * section,
       continue;
       }
     
-    if(info[i].flags & BG_PARAMETER_PLUGIN)
+    if((info[i].flags & BG_PARAMETER_PLUGIN))
       {
       section->widgets[count].plugin_reg = plugin_reg;
+
+      if(!section->cfg_section)
+        {
+        section->cfg_section = bg_cfg_section_create(NULL);
+        section->private_cfg_section = 1;
+        }
       }
     
     if((info[i].flags & BG_PARAMETER_SYNC) ||
@@ -618,83 +784,83 @@ static GtkWidget * create_section(dialog_section_t * section,
     switch(info[i].type)
       {
       case BG_PARAMETER_BUTTON:
-        bg_gtk_create_button(&(section->widgets[count]),
+        bg_gtk_create_button(&section->widgets[count],
                              translation_domain);
         break;
       case BG_PARAMETER_CHECKBUTTON:
-        bg_gtk_create_checkbutton(&(section->widgets[count]),
+        bg_gtk_create_checkbutton(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_INT:
-        bg_gtk_create_int(&(section->widgets[count]),
-                                  translation_domain);
+        bg_gtk_create_int(&section->widgets[count],
+                          translation_domain);
         break;
       case BG_PARAMETER_FLOAT:
-        bg_gtk_create_float(&(section->widgets[count]),
+        bg_gtk_create_float(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_SLIDER_INT:
-        bg_gtk_create_slider_int(&(section->widgets[count]),
+        bg_gtk_create_slider_int(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_TIME:
-        bg_gtk_create_time(&(section->widgets[count]),
+        bg_gtk_create_time(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_SLIDER_FLOAT:
-        bg_gtk_create_slider_float(&(section->widgets[count]),
+        bg_gtk_create_slider_float(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_STRING:
       case BG_PARAMETER_STRING_HIDDEN:
-        bg_gtk_create_string(&(section->widgets[count]),
+        bg_gtk_create_string(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_STRINGLIST:
-        bg_gtk_create_stringlist(&(section->widgets[count]),
+        bg_gtk_create_stringlist(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_COLOR_RGB:
-        bg_gtk_create_color_rgb(&(section->widgets[count]),
+        bg_gtk_create_color_rgb(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_COLOR_RGBA:
-        bg_gtk_create_color_rgba(&(section->widgets[count]),
+        bg_gtk_create_color_rgba(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_FILE:
-        bg_gtk_create_file(&(section->widgets[count]),
+        bg_gtk_create_file(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_DIRECTORY:
-        bg_gtk_create_directory(&(section->widgets[count]),
+        bg_gtk_create_directory(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_FONT:
-        bg_gtk_create_font(&(section->widgets[count]),
+        bg_gtk_create_font(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_DEVICE:
-        bg_gtk_create_device(&(section->widgets[count]),
+        bg_gtk_create_device(&section->widgets[count],
                                   translation_domain);
         break;
       case BG_PARAMETER_MULTI_MENU:
-        bg_gtk_create_multi_menu(&(section->widgets[count]),
+        bg_gtk_create_multi_menu(&section->widgets[count],
                                  set_param, get_param, data,
                                  translation_domain);
         break;
       case BG_PARAMETER_MULTI_LIST:
-        bg_gtk_create_multi_list(&(section->widgets[count]),
+        bg_gtk_create_multi_list(&section->widgets[count],
                                  set_param, get_param, data,
                                  translation_domain);
         break;
       case BG_PARAMETER_MULTI_CHAIN:
-        bg_gtk_create_multi_chain(&(section->widgets[count]),
+        bg_gtk_create_multi_chain(&section->widgets[count],
                                   set_param, get_param, data,
                                   translation_domain);
         break;
       case BG_PARAMETER_POSITION:
-        bg_gtk_create_position(&(section->widgets[count]),
+        bg_gtk_create_position(&section->widgets[count],
                                translation_domain);
         break;
       case BG_PARAMETER_SECTION:
@@ -706,15 +872,15 @@ static GtkWidget * create_section(dialog_section_t * section,
     /* Get the value from the config data... */
     if(section->cfg_section)
       bg_cfg_section_get_parameter(section->cfg_section, &info[i],
-                                   &(section->widgets[count].value));
+                                   &section->widgets[count].value);
     /* ... or from the get_param function */
     else if(get_param &&
-            get_param(data, info[i].name, &(section->widgets[count].value)))
+            get_param(data, info[i].name, &section->widgets[count].value))
       ;
     /* ... or from the parameter default */
     else
-      bg_parameter_value_copy(&(section->widgets[count].value),
-                              &(info[i].val_default),
+      bg_parameter_value_copy(&section->widgets[count].value,
+                              &info[i].val_default,
                               &info[i]);
     
     bg_parameter_value_copy(&section->widgets[count].last_value,
@@ -725,13 +891,50 @@ static GtkWidget * create_section(dialog_section_t * section,
       bg_gtk_change_callback_block(&section->widgets[count], 1);
     if(section->widgets[count].funcs->get_value)
       {
-      section->widgets[count].funcs->get_value(&(section->widgets[count]));    
+      section->widgets[count].funcs->get_value(&section->widgets[count]);    
       if(section->widgets[count].info->flags & BG_PARAMETER_SYNC)
         bg_gtk_change_callback_block(&section->widgets[count], 0);
       }
     i++;
     count++;
     }
+
+  if(section->cfg_section)
+    {
+    /* Create action box */
+    gtk_table_resize(GTK_TABLE(table), row+1, num_columns);
+
+    restore_button = create_restore_button(section);
+  
+    action_box = gtk_hbox_new(FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(action_box), restore_button, FALSE, FALSE, 0);
+
+    if(!preset_section &&
+       (info[0].preset_path || (section->num_widgets && section->widgets[0].info->preset_path)))
+      {
+      section->preset_section = bg_cfg_section_copy(section->cfg_section);
+      section->preset_menu = bg_gtk_preset_menu_create(info[0].preset_path,
+                                                       section->preset_section,
+                                                       preset_load_callback,
+                                                       preset_save_callback,
+                                                       section);
+      gtk_box_pack_start(GTK_BOX(action_box),
+                         bg_gtk_preset_menu_get_widget(section->preset_menu),
+                                                       FALSE, FALSE, 0);
+      }
+    else
+      section->preset_section = preset_section;
+    
+    gtk_widget_show(action_box);
+
+    vbox = gtk_vbox_new(FALSE, 0);
+    gtk_box_pack_end(GTK_BOX(vbox), action_box, FALSE, FALSE, 0);
+    gtk_widget_show(vbox);
+  
+    gtk_table_attach_defaults(GTK_TABLE(table), vbox, 0,
+                              num_columns-1, row, row+1);
+    }
+  
   gtk_widget_show(table);
   return table;
   }
@@ -757,6 +960,23 @@ static int count_sections(const bg_parameter_info_t * info)
   return 0;
   }
 
+static void preset_load_callback_global(void * data)
+  {
+  int i;
+  bg_dialog_t * d = data;
+  for(i = 0; i < d->root_section.num_children; i++)
+    preset_load_callback(d->root_section.children[i]);
+  }
+
+static void preset_save_callback_global(void * data)
+  {
+  int i;
+  bg_dialog_t * d = data;
+  for(i = 0; i < d->root_section.num_children; i++)
+    preset_save_callback(d->root_section.children[i]);
+  }
+
+
 bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
                                bg_set_parameter_func_t set_param,
                                bg_get_parameter_func_t get_param,
@@ -768,25 +988,47 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
   int num_sections;
   GtkWidget * label;
   GtkWidget * table;
+  
+  bg_cfg_section_t * preset_subsection;
+  
   GtkTreeIter root_iter;
   GtkTreeModel * model;
   const char * translation_domain = (const char *)0;
   bg_dialog_t * ret = create_dialog(title);
 
+  //  fprintf(stderr, "bg_dialog_create\n");
+  
   num_sections = count_sections(info);
 
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(ret->treeview));
-  
+
+  if((info->flags & BG_PARAMETER_GLOBAL_PRESET) &&
+     (info->preset_path))
+    {
+    ret->preset_section = bg_cfg_section_create(NULL);
+    
+    ret->preset_menu = bg_gtk_preset_menu_create(info->preset_path,
+                                                 ret->preset_section,
+                                                 preset_load_callback_global,
+                                                 preset_save_callback_global,
+                                                 ret);
+    gtk_box_pack_start(GTK_BOX(ret->action_box),
+                       bg_gtk_preset_menu_get_widget(ret->preset_menu),
+                       FALSE, FALSE, 0);
+    gtk_widget_show(ret->action_box);
+    }
   if(num_sections)
     {
     ret->root_section.num_children = num_sections;
     ret->root_section.children =
-      calloc(ret->root_section.num_children, sizeof(dialog_section_t));
+      calloc(ret->root_section.num_children, sizeof(*ret->root_section.children));
     
     index = 0;
-
+    
     for(i = 0; i < ret->root_section.num_children; i++)
       {
+      ret->root_section.children[i] = calloc(1, sizeof(*ret->root_section.children[i]));
+      
       if(info[index].gettext_domain)
         translation_domain = info[i].gettext_domain;
       if(info[index].gettext_directory)
@@ -799,16 +1041,21 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
       gtk_tree_store_append(GTK_TREE_STORE(model), &root_iter, NULL);
       gtk_tree_store_set(GTK_TREE_STORE(model), &root_iter, COLUMN_NAME,
                          TR_DOM(info[index].long_name), -1);
-      
-      table = create_section(&(ret->root_section.children[i]), &(info[index]),
+
+      if(ret->preset_section)
+        preset_subsection = bg_cfg_section_find_subsection(ret->preset_section, info[index].name);
+      else
+        preset_subsection = NULL;
+
+      table = create_section(ret->root_section.children[i], &info[index],
                              section, set_param, get_param, callback_data,
-                             translation_domain, ret->plugin_reg);
+                             translation_domain, ret->plugin_reg, preset_subsection);
       
-      ret->root_section.children[i].notebook_index =
+      ret->root_section.children[i]->notebook_index =
         gtk_notebook_get_n_pages(GTK_NOTEBOOK(ret->notebook));
       gtk_notebook_append_page(GTK_NOTEBOOK(ret->notebook), table, label);
 
-      ret->root_section.children[i].parent = &(ret->root_section);
+      ret->root_section.children[i]->parent = &ret->root_section;
 
       while(info[index].type == BG_PARAMETER_SECTION)
         index++;
@@ -827,9 +1074,10 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
     ret->root_section.num_children = 1;
     ret->root_section.children = calloc(ret->root_section.num_children,
                                         sizeof(*ret->root_section.children));
+    ret->root_section.children[0] = calloc(1, sizeof(*ret->root_section.children[0]));
     table =
-      create_section(ret->root_section.children, info, section, set_param, get_param,
-                     callback_data, (const char *)0, ret->plugin_reg);
+      create_section(*ret->root_section.children, info, section, set_param, get_param,
+                     callback_data, (const char *)0, ret->plugin_reg, NULL);
     gtk_notebook_append_page(GTK_NOTEBOOK(ret->notebook), table, label);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(ret->notebook), 1);
     gtk_widget_hide(ret->scrolledwindow);
@@ -861,6 +1109,8 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
   const char * translation_domain = (const char *)0;
   dialog_section_t * parent = (dialog_section_t*)_parent;
 
+  //  fprintf(stderr, "bg_dialog_add_child %s %p\n", info->name, section);
+  
   num_items = 0;
   num_sections = 0;
   
@@ -880,23 +1130,23 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
   if(!num_sections)
     {
     parent->children = realloc(parent->children,
-                            (parent->num_children+1)*sizeof(dialog_section_t));
-    memset(&(parent->children[parent->num_children]),0,
-           sizeof(parent->children[parent->num_children]));
+                            (parent->num_children+1)*sizeof(*parent->children));
+    parent->children[parent->num_children] =
+      calloc(1, sizeof(*parent->children[parent->num_children]));
     
-    table = create_section(&(parent->children[parent->num_children]),
+    table = create_section(parent->children[parent->num_children],
                            info, section, set_param, get_param, callback_data,
-                           (const char*)0, d->plugin_reg);
+                           (const char*)0, d->plugin_reg, NULL);
     tab_label = gtk_label_new(name);
     gtk_widget_show(tab_label);
 
-    parent->children[parent->num_children].notebook_index =
+    parent->children[parent->num_children]->notebook_index =
       gtk_notebook_get_n_pages(GTK_NOTEBOOK(d->notebook));
 
     gtk_notebook_append_page(GTK_NOTEBOOK(d->notebook),
                              table, tab_label);
 
-    if(parent == &(d->root_section))
+    if(parent == &d->root_section)
       {
       gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
       }
@@ -909,7 +1159,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
     gtk_tree_store_set(GTK_TREE_STORE(model), &iter, COLUMN_NAME,
                        name, -1);
     
-    parent->children[parent->num_children].parent = parent;
+    parent->children[parent->num_children]->parent = parent;
     
     parent->num_children++;
     }
@@ -918,14 +1168,12 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
     parent->children = realloc(parent->children,
                                (parent->num_children+num_sections)*
                                sizeof(dialog_section_t));
-
-    memset(&(parent->children[parent->num_children]),0,
-           sizeof(parent->children[parent->num_children]) * num_sections);
-    
     item_index = 0;
     section_index = parent->num_children;
     for(i = 0; i < num_sections; i++)
       {
+      parent->children[section_index] = calloc(1, sizeof(*parent->children[section_index]));
+      
       if(info[item_index].gettext_domain)
         translation_domain = info[item_index].gettext_domain;
       if(info[item_index].gettext_directory)
@@ -934,7 +1182,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
       tab_label = gtk_label_new(TR_DOM(info[item_index].long_name));
       gtk_widget_show(tab_label);
       
-      if(parent == &(d->root_section))
+      if(parent == &d->root_section)
         {
         parent = (dialog_section_t*)_parent;
         gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
@@ -948,14 +1196,14 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
       gtk_tree_store_set(GTK_TREE_STORE(model), &iter, COLUMN_NAME,
                          info[item_index].long_name, -1);
       
-      table = create_section(&(parent->children[section_index]),
-                             &(info[item_index]),
+      table = create_section(parent->children[section_index],
+                             &info[item_index],
                              section, set_param, get_param, callback_data,
-                             translation_domain, d->plugin_reg);
+                             translation_domain, d->plugin_reg, NULL);
       
-      parent->children[section_index].parent = parent;
+      parent->children[section_index]->parent = parent;
 
-      parent->children[section_index].notebook_index =
+      parent->children[section_index]->notebook_index =
         gtk_notebook_get_n_pages(GTK_NOTEBOOK(d->notebook));
       
       gtk_notebook_append_page(GTK_NOTEBOOK(d->notebook),
@@ -980,7 +1228,7 @@ void bg_dialog_add(bg_dialog_t *d,
                    void * callback_data,
                    const bg_parameter_info_t * info)
   {
-  bg_dialog_add_child(d, &(d->root_section), name,
+  bg_dialog_add_child(d, &d->root_section, name,
                       section, set_param, get_param, callback_data, info);
   }
 
@@ -1016,7 +1264,7 @@ static void destroy_section(dialog_section_t * s)
     {
     for(i = 0; i < s->num_widgets; i++)
       {
-      s->widgets[i].funcs->destroy(&(s->widgets[i]));
+      s->widgets[i].funcs->destroy(&s->widgets[i]);
       bg_parameter_value_free(&s->widgets[i].value,
                               s->widgets[i].info->type);
       bg_parameter_value_free(&s->widgets[i].last_value,
@@ -1030,15 +1278,26 @@ static void destroy_section(dialog_section_t * s)
     {
     for(i = 0; i < s->num_children; i++)
       {
-      destroy_section(&(s->children[i]));
+      destroy_section(s->children[i]);
+      free(s->children[i]);
       }
     free(s->children);
     }
+
+  if(s->preset_menu)
+    {
+    bg_gtk_preset_menu_destroy(s->preset_menu);
+    if(s->preset_section)
+      bg_cfg_section_destroy(s->preset_section);
+    }
+
+  if(s->private_cfg_section)
+    bg_cfg_section_destroy(s->cfg_section);
   }
 
 void bg_dialog_destroy(bg_dialog_t * d)
   {
-  destroy_section(&(d->root_section));
+  destroy_section(&d->root_section);
   gtk_widget_destroy(d->window);
 
   free(d);
@@ -1052,7 +1311,7 @@ void bg_gtk_change_callback(GtkWidget * gw, gpointer data)
   if(w->change_callback)
     {
     w->change_callback(w->change_callback_data,
-                       w->info->name, &(w->value));
+                       w->info->name, &w->value);
     if(w->funcs->apply_sub_params)
       w->funcs->apply_sub_params(w);
     w->change_callback(w->change_callback_data,
@@ -1093,7 +1352,7 @@ void * bg_dialog_add_parent(bg_dialog_t *d, void * _parent, const char * label)
     }
   else
     {
-    parent = &(d->root_section);
+    parent = &d->root_section;
     gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL);
     }
 
@@ -1104,13 +1363,11 @@ void * bg_dialog_add_parent(bg_dialog_t *d, void * _parent, const char * label)
   parent->children = realloc(parent->children,
                              sizeof(*(parent->children))*(parent->num_children+1));
 
-  memset(&(parent->children[parent->num_children]),0,
-         sizeof(parent->children[parent->num_children]));
-
-  parent->children[parent->num_children].parent = parent;
+  parent->children[parent->num_children] = calloc(1, sizeof(*parent->children[parent->num_children]));
+  parent->children[parent->num_children]->parent = parent;
   
   parent->num_children++;
-  return &(parent->children[parent->num_children-1]);
+  return parent->children[parent->num_children-1];
   }
 
 void bg_dialog_set_plugin_registry(bg_dialog_t * d, bg_plugin_registry_t * plugin_reg)
