@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -672,7 +672,7 @@ static gboolean configure_callback(GtkWidget * w, GdkEventConfigure *event,
   win->y = event->y;
   win->width = event->width;
   win->height = event->height;
-  gdk_window_get_root_origin(win->window->window, &(win->x), &(win->y));
+  gdk_window_get_root_origin(win->window->window, &win->x, &win->y);
   return FALSE;
   }
 
