@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -211,10 +211,10 @@ void bg_gtk_tree_window_hide(bg_gtk_tree_window_t* w)
   if(w->window->window)
     {
     gdk_window_get_geometry(w->window->window,
-                            (gint *)0, (gint *)0, &(w->width), &(w->height),
+                            (gint *)0, (gint *)0, &w->width, &w->height,
                             (gint *)0);
 
-    gdk_window_get_root_origin(w->window->window, &(w->x), &(w->y));
+    gdk_window_get_root_origin(w->window->window, &w->x, &w->y);
 
     bg_cfg_section_get(w->cfg_section,
                        parameters,
