@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -687,7 +687,8 @@ static void draw_dynamic(bg_gtk_vumeter_t * m)
   {
   int i;
 
-  if(!GTK_WIDGET_REALIZED(m->layout) || !m->pixmap_width || !m->pixmap_height)
+  if(!bg_gtk_widget_is_realized(m->layout) ||
+     !m->pixmap_width || !m->pixmap_height)
     return;
   
   if(!m->pixmaps_valid)
@@ -845,7 +846,7 @@ bg_gtk_vumeter_create(int num_channels, int vertical)
   
   ret->max_peak_age = 44100;
   
-  pthread_mutex_init(&(ret->analysis_mutex), (pthread_mutexattr_t*)0);
+  pthread_mutex_init(&ret->analysis_mutex, (pthread_mutexattr_t*)0);
   return ret;
   }
 
@@ -915,9 +916,9 @@ void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
 
 void bg_gtk_vumeter_draw(bg_gtk_vumeter_t * m)
   {
-  pthread_mutex_lock(&(m->analysis_mutex));
+  pthread_mutex_lock(&m->analysis_mutex);
   draw_dynamic(m);
-  pthread_mutex_unlock(&(m->analysis_mutex));
+  pthread_mutex_unlock(&m->analysis_mutex);
   flash(m);
   }
 
