@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -160,6 +160,7 @@ void bg_parameter_info_copy(bg_parameter_info_t * dst,
 
   dst->gettext_domain    = bg_strdup(dst->gettext_domain,    src->gettext_domain);
   dst->gettext_directory = bg_strdup(dst->gettext_directory, src->gettext_directory);
+  dst->preset_path = bg_strdup(dst->preset_path, src->preset_path);
   
   switch(dst->type)
     {
@@ -287,7 +288,7 @@ bg_parameter_info_copy_array(const bg_parameter_info_t * src)
   ret = calloc(num_parameters + 1, sizeof(bg_parameter_info_t));
   
   for(i = 0; i < num_parameters; i++)
-    bg_parameter_info_copy(&(ret[i]), &(src[i]));
+    bg_parameter_info_copy(&ret[i], &src[i]);
   
   return ret;
   }
@@ -309,6 +310,8 @@ void bg_parameter_info_destroy_array(bg_parameter_info_t * info)
       free(info[index].gettext_domain);
     if(info[index].gettext_directory)
       free(info[index].gettext_directory);
+    if(info[index].preset_path)
+      free(info[index].preset_path);
     switch(info[index].type)
       {
       case BG_PARAMETER_STRINGLIST:
@@ -383,7 +386,6 @@ bg_parameter_info_concat_arrays(bg_parameter_info_t const ** srcs)
   while(srcs[i])
     {
     j = 0;
-
     while(srcs[i][j].name)
       {
       num_parameters++;
@@ -404,24 +406,20 @@ bg_parameter_info_concat_arrays(bg_parameter_info_t const ** srcs)
   while(srcs[i])
     {
     j = 0;
-    
     while(srcs[i][j].name)
       {
-      bg_parameter_info_copy(&(ret[dst]), &(srcs[i][j]));
+      bg_parameter_info_copy(&ret[dst], &srcs[i][j]);
       dst++;
       j++;
       }
     i++;
     }
-
-  
   return ret;
   }
 
 int bg_parameter_get_selected(const bg_parameter_info_t * info,
                               const char * val)
   {
-  
   int ret = -1, i;
 
   if(val)
@@ -495,6 +493,7 @@ void bg_parameter_info_set_const_ptrs(bg_parameter_info_t * ret)
   ret->multi_names = (char const **)ret->multi_names_nc;
   ret->multi_labels = (char const **)ret->multi_labels_nc;
   ret->multi_descriptions = (char const **)ret->multi_descriptions_nc;
-  ret->multi_parameters = (bg_parameter_info_t const * const *)ret->multi_parameters_nc;
+  ret->multi_parameters =
+    (bg_parameter_info_t const * const *)ret->multi_parameters_nc;
   }
   
