@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -88,11 +88,12 @@ static const struct
   }
 flag_names[] =
   {
-    { "sync",        BG_PARAMETER_SYNC        },
-    { "hide_dialog", BG_PARAMETER_HIDE_DIALOG },
-    { "no_sort",     BG_PARAMETER_NO_SORT     },
-    { "plugin",      BG_PARAMETER_PLUGIN      },
-    { "own_section", BG_PARAMETER_OWN_SECTION },
+    { "sync",          BG_PARAMETER_SYNC          },
+    { "hide_dialog",   BG_PARAMETER_HIDE_DIALOG   },
+    { "no_sort",       BG_PARAMETER_NO_SORT       },
+    { "plugin",        BG_PARAMETER_PLUGIN        },
+    { "own_section",   BG_PARAMETER_OWN_SECTION   },
+    { "global_preset", BG_PARAMETER_GLOBAL_PRESET },
   };
 
 static int string_to_flags(const char * str)
@@ -167,6 +168,8 @@ static const char * const multi_parameter_key  = "MULTI_PARAMETER";
 static const char * const gettext_domain_key     = "GETTEXT_DOMAIN";
 static const char * const gettext_directory_key  = "GETTEXT_DIRECTORY";
 
+static const char * const preset_path_key  = "PRESET_PATH";
+
 /* */
 
 bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
@@ -251,6 +254,12 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
           ret[index].gettext_directory = bg_strdup(ret[index].gettext_directory, tmp_string);
           free(tmp_string);
           }
+        else if(!BG_XML_STRCMP(child->name, preset_path_key))
+          {
+          tmp_string = (char*)xmlNodeListGetString(xml_doc, child->children, 1);
+          ret[index].preset_path = bg_strdup(ret[index].preset_path, tmp_string);
+          free(tmp_string);
+          }
         else if(!BG_XML_STRCMP(child->name, multi_names_key))
           {
           tmp_string = BG_XML_GET_PROP(child, num_key);
@@ -379,11 +388,11 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
             case BG_PARAMETER_SLIDER_INT:
             case BG_PARAMETER_CHECKBUTTON:
             case BG_PARAMETER_INT:
-              sscanf(tmp_string, "%d", &(ret[index].val_default.val_i));
+              sscanf(tmp_string, "%d", &ret[index].val_default.val_i);
               break;
             case BG_PARAMETER_FLOAT:
             case BG_PARAMETER_SLIDER_FLOAT:
-              sscanf(tmp_string, "%lf", &(ret[index].val_default.val_f));
+              sscanf(tmp_string, "%lf", &ret[index].val_default.val_f);
               break;
             case BG_PARAMETER_STRING:
             case BG_PARAMETER_STRINGLIST:
@@ -399,24 +408,24 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
               break;
             case BG_PARAMETER_COLOR_RGB:
               sscanf(tmp_string, "%f %f %f",
-                     &(ret[index].val_default.val_color[0]),
-                     &(ret[index].val_default.val_color[1]),
-                     &(ret[index].val_default.val_color[2]));
+                     &ret[index].val_default.val_color[0],
+                     &ret[index].val_default.val_color[1],
+                     &ret[index].val_default.val_color[2]);
               break;
             case BG_PARAMETER_COLOR_RGBA:
               sscanf(tmp_string, "%f %f %f %f",
-                     &(ret[index].val_default.val_color[0]),
-                     &(ret[index].val_default.val_color[1]),
-                     &(ret[index].val_default.val_color[2]),
-                     &(ret[index].val_default.val_color[3]));
+                     &ret[index].val_default.val_color[0],
+                     &ret[index].val_default.val_color[1],
+                     &ret[index].val_default.val_color[2],
+                     &ret[index].val_default.val_color[3]);
               break;
             case BG_PARAMETER_POSITION:
               sscanf(tmp_string, "%lf %lf",
-                     &(ret[index].val_default.val_pos[0]),
-                     &(ret[index].val_default.val_pos[1]));
+                     &ret[index].val_default.val_pos[0],
+                     &ret[index].val_default.val_pos[1]);
               break;
             case BG_PARAMETER_TIME:
-              sscanf(tmp_string, "%" PRId64, &(ret[index].val_default.val_time));
+              sscanf(tmp_string, "%" PRId64, &ret[index].val_default.val_time);
               break;
             }
           free(tmp_string);
@@ -447,19 +456,19 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
             case BG_PARAMETER_SLIDER_INT:
             case BG_PARAMETER_INT:
               sscanf(tmp_string, "%d %d",
-                     &(ret[index].val_min.val_i),
-                     &(ret[index].val_max.val_i));
+                     &ret[index].val_min.val_i,
+                     &ret[index].val_max.val_i);
               break;
             case BG_PARAMETER_FLOAT:
             case BG_PARAMETER_SLIDER_FLOAT:
               sscanf(tmp_string, "%lf %lf",
-                     &(ret[index].val_min.val_f),
-                     &(ret[index].val_max.val_f));
+                     &ret[index].val_min.val_f,
+                     &ret[index].val_max.val_f);
               break;
             case BG_PARAMETER_TIME:
               sscanf(tmp_string, "%" PRId64 " %" PRId64,
-                     &(ret[index].val_min.val_time),
-                     &(ret[index].val_max.val_time));
+                     &ret[index].val_min.val_time,
+                     &ret[index].val_max.val_time);
               break;
             }
           free(tmp_string);
@@ -468,7 +477,7 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
         else if(!BG_XML_STRCMP(child->name, num_digits_key))
           {
           tmp_string = (char*)xmlNodeListGetString(xml_doc, child->children, 1);
-          sscanf(tmp_string, "%d", &(ret[index].num_digits));
+          sscanf(tmp_string, "%d", &ret[index].num_digits);
           free(tmp_string);
           }
         
@@ -487,7 +496,8 @@ bg_parameter_info_t * bg_xml_2_parameters(xmlDocPtr xml_doc,
 
 /* */
 
-void bg_parameters_2_xml(const bg_parameter_info_t * info, xmlNodePtr xml_parameters)
+void bg_parameters_2_xml(const bg_parameter_info_t * info,
+                         xmlNodePtr xml_parameters)
   {
   int multi_num, i;
   xmlNodePtr xml_info;
@@ -546,6 +556,12 @@ void bg_parameters_2_xml(const bg_parameter_info_t * info, xmlNodePtr xml_parame
       xmlAddChild(child, BG_XML_NEW_TEXT(info[num_parameters].gettext_directory));
       xmlAddChild(xml_info, BG_XML_NEW_TEXT("\n"));
       }
+    if(info[num_parameters].preset_path)
+      {
+      child = xmlNewTextChild(xml_info, (xmlNsPtr)0, (xmlChar*)preset_path_key, NULL);
+      xmlAddChild(child, BG_XML_NEW_TEXT(info[num_parameters].preset_path));
+      xmlAddChild(xml_info, BG_XML_NEW_TEXT("\n"));
+      }
     
     multi_num = 0;
     if(info[num_parameters].multi_names)
