@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -33,7 +33,7 @@
 
 #define DEBUG_COUNTER
 
-#if 1
+#if 0
 struct bg_player_input_context_s
   {
   /* Plugin stuff */
@@ -155,11 +155,11 @@ void bg_player_input_select_streams(bg_player_t * p)
     
     p->flags |= PLAYER_DO_SUBTITLE_ONLY;
     
-    pthread_mutex_lock(&(p->video_stream.config_mutex));
+    pthread_mutex_lock(&p->video_stream.config_mutex);
     /* Get background color */
     gavl_video_options_get_background_color(p->video_stream.options.opt,
                                             vs->bg_color);
-    pthread_mutex_unlock(&(p->video_stream.config_mutex));
+    pthread_mutex_unlock(&p->video_stream.config_mutex);
     
     vs->bg_color[3] = 1.0;
     }
@@ -285,7 +285,7 @@ int bg_player_input_init(bg_player_t * p,
   if(p->input_plugin->set_callbacks)
     {
     p->input_plugin->set_callbacks(p->input_priv,
-                                   &(p->input_callbacks));
+                                   &p->input_callbacks);
     }
   
   p->track_info = p->input_plugin->get_track_info(p->input_priv,
@@ -331,7 +331,9 @@ int bg_player_input_init(bg_player_t * p,
 
 void bg_player_input_cleanup(bg_player_t * p)
   {
-  
+#ifdef DEBUG_COUNTER
+  char tmp_string[128];
+#endif  
   bg_player_input_stop(p);
   if(p->input_handle)
     bg_plugin_unref(p->input_handle);
@@ -343,15 +345,14 @@ void bg_player_input_cleanup(bg_player_t * p)
     gavl_video_frame_destroy(p->video_stream.still_frame_in);
     p->video_stream.still_frame_in = (gavl_video_frame_t*)0;
     }
-  // #ifdef DEBUG_COUNTER
-#if 0
-  sprintf(tmp_string, "%" PRId64, ctx->audio_sample_counter);
+#ifdef DEBUG_COUNTER
+  sprintf(tmp_string, "%" PRId64, p->audio_stream.samples_read);
   
   bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Audio sample counter: %s",
          tmp_string);
 
-  sprintf(tmp_string, "%" PRId64, ctx->video_frame_counter);
-
+  sprintf(tmp_string, "%" PRId64, p->video_stream.frames_read);
+  
   bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Video frame counter: %s",
          tmp_string);
 #endif
@@ -359,15 +360,15 @@ void bg_player_input_cleanup(bg_player_t * p)
 
 int bg_player_input_get_audio_format(bg_player_t * p)
   {
-  gavl_audio_format_copy(&(p->audio_stream.input_format),
-                         &(p->track_info->audio_streams[p->current_audio_stream].format));
+  gavl_audio_format_copy(&p->audio_stream.input_format,
+                         &p->track_info->audio_streams[p->current_audio_stream].format);
   return 1;
   }
 
 int bg_player_input_get_video_format(bg_player_t * p)
   {
-  gavl_video_format_copy(&(p->video_stream.input_format),
-                         &(p->track_info->video_streams[p->current_video_stream].format));
+  gavl_video_format_copy(&p->video_stream.input_format,
+                         &p->track_info->video_streams[p->current_video_stream].format);
 
   if(p->video_stream.do_still)
     {
@@ -384,8 +385,8 @@ int bg_player_input_get_video_format(bg_player_t * p)
 int
 bg_player_input_get_subtitle_format(bg_player_t * p)
   {
-  gavl_video_format_copy(&(p->subtitle_stream.input_format),
-                         &(p->track_info->subtitle_streams[p->current_subtitle_stream].format));
+  gavl_video_format_copy(&p->subtitle_stream.input_format,
+                         &p->track_info->subtitle_streams[p->current_subtitle_stream].format);
   return 1;
   }
 
@@ -492,6 +493,8 @@ bg_player_input_read_video(void * priv,
            gavl_time_unscale(vs->input_format.timescale,
                              frame->timestamp));
 #endif
+  p->video_stream.frames_read++;
+  
   //  if(!result)
   //    fprintf(stderr, "Read video failed\n");
   return result;
@@ -604,13 +607,13 @@ void bg_player_set_input_parameter(void * data, const char * name,
   if(!name)
     return;
 
-  pthread_mutex_lock(&(player->config_mutex));
+  pthread_mutex_lock(&player->config_mutex);
   if(!strcmp(name, "still_framerate"))
     player->still_framerate = val->val_f;
   else if(!strcmp(name, "sync_offset"))
     player->sync_offset = gavl_time_unscale(1000, val->val_i);
 
-  pthread_mutex_unlock(&(player->config_mutex));
+  pthread_mutex_unlock(&player->config_mutex);
   }
 
 struct msg_input_data
