@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -27,6 +27,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <errno.h>
 
 #include <config.h>
 #include <gmerlin/translation.h>
@@ -38,12 +39,10 @@
 #include <config.h>
 #include <gmerlin/utils.h>
 #include <gmerlin/singlepic.h>
+#include <gmerlin/log.h>
 
-#if 0
-char * bg_singlepic_ouput_name = "e_singlepic";
-char * bg_singlepic_input_name = "i_singlepic";
-char * bg_singlepic_stills_input_name = "i_singlepic_stills";
-#endif
+#define LOG_DOMAIN_ENC "singlepicture-encoder"
+#define LOG_DOMAIN_DEC "singlepicture-decoder"
 
 static char * get_extensions(bg_plugin_registry_t * reg,
                              uint32_t type_mask, uint32_t flag_mask)
@@ -145,7 +144,7 @@ static const bg_parameter_info_t * get_parameters_input_still(void * priv)
 static void set_parameter_input(void * priv, const char * name,
                                 const bg_parameter_value_t * val)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
 
   if(!name)
     return;
@@ -170,17 +169,16 @@ static void set_parameter_input(void * priv, const char * name,
 static int open_input(void * priv, const char * filename)
   {
   const bg_plugin_info_t * info;
-  struct stat stat_buf;
   char * tmp_string;
   const char * pos;
   const char * pos_start;
   const char * pos_end;
   
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   
   /* Check if the first file exists */
   
-  if(stat(filename, &stat_buf))
+  if(access(filename, R_OK))
     return 0;
   
   /* Load plugin */
@@ -237,12 +235,12 @@ static int open_input(void * priv, const char * filename)
   inp->frame_start = strtoll(pos_start, NULL, 10);
   inp->frame_end = inp->frame_start+1;
 
-  inp->filename_buffer = malloc(strlen(filename)+1);
+  inp->filename_buffer = malloc(strlen(filename)+100);
 
   while(1)
     {
     sprintf(inp->filename_buffer, inp->template, inp->frame_end);
-    if(stat(inp->filename_buffer, &stat_buf))
+    if(access(inp->filename_buffer, R_OK))
       break;
     inp->frame_end++;
     }
@@ -252,6 +250,9 @@ static int open_input(void * priv, const char * filename)
   inp->track_info.num_video_streams = 1;
   inp->track_info.video_streams =
     calloc(1, sizeof(*inp->track_info.video_streams));
+
+  inp->track_info.video_streams[0].description =
+    bg_strdup(NULL, "Single images");
   
   inp->track_info.duration = gavl_frames_to_time(inp->timescale,
                                                  inp->frame_duration,
@@ -260,21 +261,37 @@ static int open_input(void * priv, const char * filename)
   
   /* Get track name */
 
-  bg_set_track_name_default(&(inp->track_info), filename);
+  bg_set_track_name_default(&inp->track_info, filename);
   
   inp->track_info.flags |= (BG_TRACK_SEEKABLE|BG_TRACK_PAUSABLE);
+
+  inp->current_frame = inp->frame_start;
+
+  sprintf(inp->filename_buffer, inp->template, inp->current_frame);
+
+  if(!inp->image_reader->read_header(inp->handle->priv,
+                                     inp->filename_buffer,
+                                     &inp->track_info.video_streams[0].format))
+    return 0;
+  inp->track_info.video_streams[0].format.timescale =
+    inp->timescale;
+  inp->track_info.video_streams[0].format.frame_duration =
+    inp->frame_duration;
+  inp->track_info.video_streams[0].format.framerate_mode =
+    GAVL_FRAMERATE_CONSTANT;
+  inp->header_read = 1;
+  
   return 1;
   }
 
 static int open_stills_input(void * priv, const char * filename)
   {
   const bg_plugin_info_t * info;
-  struct stat stat_buf;
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   
   /* Check if the first file exists */
   
-  if(stat(filename, &stat_buf))
+  if(access(filename, R_OK))
     return 0;
   
   /* First of all, check if there is a plugin for this format */
@@ -293,6 +310,9 @@ static int open_stills_input(void * priv, const char * filename)
   inp->track_info.num_video_streams = 1;
   inp->track_info.video_streams =
     calloc(1, sizeof(*inp->track_info.video_streams));
+
+  inp->track_info.video_streams[0].description =
+    bg_strdup(NULL, "Still Image");
   
   inp->track_info.video_streams[0].format.framerate_mode =
     GAVL_FRAMERATE_STILL;
@@ -301,72 +321,68 @@ static int open_stills_input(void * priv, const char * filename)
   
   /* Get track name */
 
-  bg_set_track_name_default(&(inp->track_info), filename);
+  bg_set_track_name_default(&inp->track_info, filename);
 
   inp->filename_buffer = bg_strdup(inp->filename_buffer, filename);
+
+  if(!inp->image_reader->read_header(inp->handle->priv,
+                                     inp->filename_buffer,
+                                     &inp->track_info.video_streams[0].format))
+    return 0;
+  inp->track_info.video_streams[0].format.timescale = GAVL_TIME_SCALE;
+  inp->track_info.video_streams[0].format.frame_duration = 0;
+  inp->track_info.video_streams[0].format.framerate_mode = GAVL_FRAMERATE_STILL;
+  inp->header_read = 1;
+
   return 1;
 
   }
 
 static bg_track_info_t * get_track_info_input(void * priv, int track)
   {
-  input_t * inp = (input_t *)priv;
-  return &(inp->track_info);
+  input_t * inp = priv;
+  return &inp->track_info;
   }
 
 static int set_video_stream_input(void * priv, int stream,
                                   bg_stream_action_t action)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   inp->action = action;
+
+  /* Close image reader */
+  if(inp->action == BG_STREAM_ACTION_READRAW)
+    {
+    /* Unload the plugin */
+    if(inp->handle)
+      bg_plugin_unref(inp->handle);
+    inp->handle = NULL;
+    inp->image_reader = NULL;
+    }
+  
   return 1;
   }
 
+static int get_compression_info_input(void * priv, int stream,
+                                      gavl_compression_info_t * ci)
+  {
+  int ret;
+  input_t * inp = priv;
+  if(!inp->image_reader || !inp->image_reader->get_compression_info)
+    return 0;
+  ret = inp->image_reader->get_compression_info(inp->handle->priv, ci);
+
+  if(ret)
+    {
+    if(gavl_compression_need_pixelformat(ci->id) &&
+       (inp->track_info.video_streams[0].format.pixelformat == GAVL_PIXELFORMAT_NONE))
+      return 0;
+    }
+  return ret;
+  }
+
 static int start_input(void * priv)
   {
-  input_t * inp = (input_t *)priv;
-
-  if(inp->action != BG_STREAM_ACTION_DECODE)
-    return 1;
-
-  inp->current_frame = inp->frame_start;
-  
-  if(inp->do_still)
-    {
-    inp->track_info.video_streams[0].description =
-      bg_strdup(NULL, "Still Image");
-    }
-  else
-    {
-    inp->track_info.video_streams[0].description =
-      bg_strdup(NULL, "Single images");
-    sprintf(inp->filename_buffer, inp->template, inp->current_frame);
-    }
-  
-  if(inp->do_still)
-    {
-    if(!inp->image_reader->read_header(inp->handle->priv,
-                                       inp->filename_buffer,
-                                       &(inp->track_info.video_streams[0].format)))
-      return 0;
-    inp->track_info.video_streams[0].format.timescale = GAVL_TIME_SCALE;
-    inp->track_info.video_streams[0].format.frame_duration = 0;
-    inp->track_info.video_streams[0].format.framerate_mode = GAVL_FRAMERATE_STILL;
-    }
-  else
-    {
-    if(!inp->image_reader->read_header(inp->handle->priv,
-                                       inp->filename_buffer,
-                                       &(inp->track_info.video_streams[0].format)))
-      return 0;
-    inp->track_info.video_streams[0].format.timescale =
-      inp->timescale;
-    inp->track_info.video_streams[0].format.frame_duration =
-      inp->frame_duration;
-    inp->track_info.video_streams[0].format.framerate_mode =
-      GAVL_FRAMERATE_CONSTANT;
-    }
-  inp->header_read = 1;
   return 1;
   }
 
@@ -379,7 +395,7 @@ static int read_video_frame_input(void * priv, gavl_video_frame_t* f,
                                   int stream)
   {
   gavl_video_format_t format;
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   
   if(inp->do_still)
     {
@@ -391,7 +407,8 @@ static int read_video_frame_input(void * priv, gavl_video_frame_t* f,
   
   if(!inp->header_read)
     {
-    sprintf(inp->filename_buffer, inp->template, inp->current_frame);
+    if(!inp->do_still)
+      sprintf(inp->filename_buffer, inp->template, inp->current_frame);
     
     if(!inp->image_reader->read_header(inp->handle->priv,
                                        inp->filename_buffer,
@@ -405,6 +422,9 @@ static int read_video_frame_input(void * priv, gavl_video_frame_t* f,
   if(f)
     {
     f->timestamp = (inp->current_frame - inp->frame_start) * inp->frame_duration;
+
+    if(!inp->do_still)
+      f->duration = inp->frame_duration;
     }
   inp->header_read = 0;
   inp->current_frame++;
@@ -412,9 +432,54 @@ static int read_video_frame_input(void * priv, gavl_video_frame_t* f,
   return 1;
   }
 
+static int read_video_packet_input(void * priv, int stream, gavl_packet_t* p)
+  {
+  FILE * in;
+  int64_t size;
+  input_t * inp = priv;
+  
+  sprintf(inp->filename_buffer, inp->template, inp->current_frame);
+  
+  if(inp->do_still)
+    {
+    if(inp->current_frame)
+      return 0;
+    }
+  else if(inp->current_frame == inp->frame_end)
+    return 0;
+  
+  in = fopen(inp->filename_buffer, "rb");
+  if(!in)
+    return 0;
+
+  fseek(in, 0, SEEK_END);
+  size = ftell(in);
+  fseek(in, 0, SEEK_SET);
+
+  gavl_packet_alloc(p, size);
+
+  p->data_len = fread(p->data, 1, size, in);
+  
+  fclose(in);
+  
+  if(p->data_len < size)
+    return 0;
+
+  p->pts = (inp->current_frame - inp->frame_start) * inp->frame_duration;
+  
+  p->flags = GAVL_PACKET_KEYFRAME;
+  
+  if(!inp->do_still)
+    p->duration = inp->frame_duration;
+
+  inp->current_frame++;
+  
+  return 1;
+  }
+
 static int set_track_input_stills(void * priv, int track)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   
   /* Reset image reader */
   inp->current_frame = 0;
@@ -429,7 +494,7 @@ static int set_track_input_stills(void * priv, int track)
 
 static void seek_input(void * priv, int64_t * time, int scale)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   int64_t time_scaled = gavl_time_rescale(scale, inp->timescale, *time);
   
   inp->current_frame = inp->frame_start + time_scaled / inp->frame_duration;
@@ -441,14 +506,14 @@ static void seek_input(void * priv, int64_t * time, int scale)
 
 static void stop_input(void * priv)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   if(inp->action != BG_STREAM_ACTION_DECODE)
     return;
   }
 
 static void close_input(void * priv)
   {
-  input_t * inp = (input_t *)priv;
+  input_t * inp = priv;
   if(inp->template)
     {
     free(inp->template);
@@ -459,7 +524,7 @@ static void close_input(void * priv)
     free(inp->filename_buffer);
     inp->filename_buffer = (char*)0;
     }
-  bg_track_info_free(&(inp->track_info));
+  bg_track_info_free(&inp->track_info);
   
   /* Unload the plugin */
   if(inp->handle)
@@ -495,6 +560,7 @@ static const bg_input_plugin_t input_plugin =
     //    .get_num_tracks = bg_avdec_get_num_tracks,
 
     .get_track_info = get_track_info_input,
+    .get_video_compression_info = get_compression_info_input,
     /* Set streams */
     .set_video_stream =      set_video_stream_input,
     /*
@@ -506,6 +572,7 @@ static const bg_input_plugin_t input_plugin =
     .start =                 start_input,
     /* Read one video frame (returns FALSE on EOF) */
     .read_video =      read_video_frame_input,
+    .read_video_packet = read_video_packet_input,
     /*
      *  Do percentage seeking (can be NULL)
      *  Media streams are supposed to be seekable, if this
@@ -611,7 +678,8 @@ bg_plugin_info_t * bg_singlepic_input_info(bg_plugin_registry_t * reg)
   {
   bg_plugin_info_t * ret;
   ret = get_input_info(reg, &input_plugin);
-  ret->parameters = bg_parameter_info_copy_array(parameters_input);
+  if(ret)
+    ret->parameters = bg_parameter_info_copy_array(parameters_input);
   return ret;
   }
 
@@ -619,7 +687,8 @@ bg_plugin_info_t * bg_singlepic_stills_input_info(bg_plugin_registry_t * reg)
   {
   bg_plugin_info_t * ret;
   ret = get_input_info(reg, &input_plugin_stills);
-  ret->parameters = bg_parameter_info_copy_array(parameters_input_still);
+  if(ret)
+    ret->parameters = bg_parameter_info_copy_array(parameters_input_still);
   return ret;
   }
 
@@ -673,7 +742,7 @@ static const bg_parameter_info_t parameters_encoder[] =
 
 typedef struct
   {
-  char * first_filename;
+  char * filename_base;
   
   bg_plugin_handle_t * plugin_handle;
   bg_image_writer_plugin_t * image_writer;
@@ -687,8 +756,6 @@ typedef struct
   int frame_digits, frame_offset;
   int64_t frame_counter;
   
-  char * extension;
-  char * extension_mask;
   char * mask;
   char * filename_buffer;
   
@@ -700,6 +767,8 @@ typedef struct
   
   bg_iw_callbacks_t iw_callbacks;
   
+  const gavl_compression_info_t * ci;
+  
   } encoder_t;
 
 static int iw_callbacks_create_output_file(void * priv, const char * filename)
@@ -781,57 +850,37 @@ static void set_callbacks_encoder(void * data, bg_encoder_callbacks_t * cb)
   e->cb = cb;
   }
 
+static void create_mask(encoder_t * e, const char * ext)
+  {
+  char * tmp_string;
+  int filename_len;
+  e->mask = bg_strdup(e->mask, e->filename_base);
+  
+  tmp_string = bg_sprintf("-%%0%d"PRId64".%s", e->frame_digits, ext);
+  e->mask = bg_strcat(e->mask, tmp_string);
+  free(tmp_string);
+  
+  filename_len = strlen(e->filename_base) + e->frame_digits + strlen(ext) + 16;
+  e->filename_buffer = malloc(filename_len);
+  }
+
 static int open_encoder(void * data, const char * filename,
                         const bg_metadata_t * metadata,
                         const bg_chapter_list_t * chapter_list)
   {
   encoder_t * e;
-  int filename_len;
   
   e = (encoder_t *)data;
-
-  /* Create the final mask */
-
-  e->mask = bg_strdup(e->mask, filename);
-
-  filename_len = strlen(filename);
-
-  if(!e->extension)
-    {
-    char ** extensions;
-
-    extensions = bg_strbreak(e->image_writer->extensions, ' ');
-    
-    /* Create extension */
-    
-    e->extension_mask = bg_sprintf("-%%0%d"PRId64".%s", e->frame_digits, extensions[0]);
-    e->extension      = bg_sprintf(e->extension_mask, (int64_t)e->frame_offset);
-    
-    bg_strbreak_free(extensions);
-    }
   
-  e->mask = bg_strcat(e->mask, e->extension_mask);
-
-
-  e->filename_buffer = malloc(filename_len+1);
-
   e->frame_counter = e->frame_offset;
-
-  e->first_filename = bg_sprintf(e->mask, e->frame_counter);
-
+  e->filename_base = bg_strdup(e->filename_base, filename);
+  
   if(metadata)
     bg_metadata_copy(&e->metadata, metadata);
   
   return 1;
   }
 
-static const char * get_filename_encoder(void * data)
-  {
-  encoder_t * e;
-  e = (encoder_t *)data;
-  return e->first_filename;
-  }
-
 static int write_frame_header(encoder_t * e)
   {
   int ret;
@@ -843,7 +892,7 @@ static int write_frame_header(encoder_t * e)
   
   ret = e->image_writer->write_header(e->plugin_handle->priv,
                                       e->filename_buffer,
-                                      &(e->format), &e->metadata);
+                                      &e->format, &e->metadata);
   
   if(!ret)
     {
@@ -857,29 +906,58 @@ static int start_encoder(void * data)
   {
   encoder_t * e;
   e = (encoder_t *)data;
-  return e->have_header;
+  return (e->have_header || e->ci) ? 1 : 0;
   }
-     
+
+static int writes_compressed_video(void * priv,
+                                   const gavl_video_format_t * format,
+                                   const gavl_compression_info_t * info)
+  {
+  int separate = 0;
+  
+  if(gavl_compression_get_extension(info->id, &separate) &&
+     separate)
+    return 1;
+  return 0;
+  }
+
+
+
 static int add_video_stream_encoder(void * data, const gavl_video_format_t * format)
   {
-  encoder_t * e;
-  e = (encoder_t *)data;
-
-  gavl_video_format_copy(&(e->format), format);
+  char ** extensions;
+  encoder_t * e = data;
+  
+  gavl_video_format_copy(&e->format, format);
 
+  extensions = bg_strbreak(e->image_writer->extensions, ' ');
+  create_mask(e, extensions[0]);
+  bg_strbreak_free(extensions);
+  
   /* Write image header so we know the format */
   
   write_frame_header(e);
   return 0;
   }
 
+static int
+add_video_stream_compressed_encoder(void * data, const gavl_video_format_t * format,
+                                    const gavl_compression_info_t * info)
+  {
+  encoder_t * e;
+  e = (encoder_t *)data;
+  e->ci = info;
+  create_mask(e, gavl_compression_get_extension(e->ci->id, NULL));
+  return 0;
+  }
+
 static void get_video_format_encoder(void * data, int stream,
                                      gavl_video_format_t * format)
   {
   encoder_t * e;
 
   e = (encoder_t *)data;
-  gavl_video_format_copy(format, &(e->format));
+  gavl_video_format_copy(format, &e->format);
   }
 
 static int
@@ -892,9 +970,7 @@ write_video_frame_encoder(void * data, gavl_video_frame_t * frame,
   e = (encoder_t *)data;
 
   if(!e->have_header)
-    {
     ret = write_frame_header(e);
-    }
   if(ret)
     ret = e->image_writer->write_image(e->plugin_handle->priv, frame);
   
@@ -902,14 +978,41 @@ write_video_frame_encoder(void * data, gavl_video_frame_t * frame,
   return ret;
   }
 
+static int write_video_packet_encoder(void * data, gavl_packet_t * packet,
+                                      int stream)
+  {
+  FILE * out;
+  encoder_t * e = data;
+  sprintf(e->filename_buffer, e->mask, e->frame_counter);
+
+  if(!bg_encoder_cb_create_output_file(e->cb, e->filename_buffer))
+    return 0;
+  out = fopen(e->filename_buffer, "wb");
+  if(!out)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN_ENC, "Cannot open file %s: %s",
+           e->filename_buffer, strerror(errno));
+    return 0;
+    }
+  
+  if(fwrite(packet->data, 1, packet->data_len, out) < packet->data_len)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN_ENC, "Couldn't write data to %s: %s",
+           e->filename_buffer, strerror(errno));
+    return 0;
+    }
+  fclose(out);
+  e->frame_counter++;
+  return 1;
+  }
+
 #define STR_FREE(s) if(s){free(s);s=(char*)0;}
 
 static int close_encoder(void * data, int do_delete)
   {
   int64_t i;
   
-  encoder_t * e;
-  e = (encoder_t *)data;
+  encoder_t * e = data;
 
   if(do_delete)
     {
@@ -920,11 +1023,9 @@ static int close_encoder(void * data, int do_delete)
       }
     }
   
-  STR_FREE(e->extension);
-  STR_FREE(e->extension_mask);
   STR_FREE(e->mask);
   STR_FREE(e->filename_buffer);
-  STR_FREE(e->first_filename);
+  STR_FREE(e->filename_base);
   
   bg_metadata_free(&e->metadata);
   
@@ -979,15 +1080,19 @@ const bg_encoder_plugin_t encoder_plugin =
     .set_callbacks =     set_callbacks_encoder,
     
     .open =              open_encoder,
-    .get_filename =      get_filename_encoder,
+
+    .writes_compressed_video = writes_compressed_video,
     
     .add_video_stream =  add_video_stream_encoder,
+    .add_video_stream_compressed =  add_video_stream_compressed_encoder,
     
     .get_video_format =  get_video_format_encoder,
 
     .start =             start_encoder,
     
     .write_video_frame = write_video_frame_encoder,
+    .write_video_packet = write_video_packet_encoder,
+    
     
     /* Close it */
 
