@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -69,7 +69,8 @@ static void create_sections(bg_transcoder_track_t * t,
   i = 0;
   while(t->general_parameters[i].name)
     {
-    bg_cfg_section_get_parameter(t->general_section, &(t->general_parameters[i]),
+    bg_cfg_section_get_parameter(t->general_section,
+                                 &t->general_parameters[i],
                                  (bg_parameter_value_t*)0);
     i++;
     }
@@ -465,56 +466,60 @@ void bg_transcoder_track_create_parameters(bg_transcoder_track_t * track,
   gavl_time_t duration = GAVL_TIME_UNDEFINED;
   int i;
   int flags = 0;
-  
-  track->general_parameters = bg_parameter_info_copy_array(parameters_general);
 
-  bg_cfg_section_get_parameter_time(track->general_section,
-                                    "duration", &duration);
-  bg_cfg_section_get_parameter_int(track->general_section,
-                                   "flags", &flags);
-
-  if(duration != GAVL_TIME_UNDEFINED)
+  if(!track->general_parameters)
     {
-    i = 0;
+    track->general_parameters = bg_parameter_info_copy_array(parameters_general);
 
-    while(track->general_parameters[i].name)
-      {
-      if(!strcmp(track->general_parameters[i].name, "start_time") ||
-         !strcmp(track->general_parameters[i].name, "end_time"))
-        track->general_parameters[i].val_max.val_time = duration;
-      i++;
-      }
-
-
-    if(flags & BG_TRACK_SEEKABLE)
+    bg_cfg_section_get_parameter_time(track->general_section,
+                                      "duration", &duration);
+    bg_cfg_section_get_parameter_int(track->general_section,
+                                     "flags", &flags);
+    
+    if(duration != GAVL_TIME_UNDEFINED)
       {
       i = 0;
+      
       while(track->general_parameters[i].name)
         {
         if(!strcmp(track->general_parameters[i].name, "start_time") ||
-           !strcmp(track->general_parameters[i].name, "set_start_time"))
-          track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
+           !strcmp(track->general_parameters[i].name, "end_time"))
+          track->general_parameters[i].val_max.val_time = duration;
         i++;
         }
+
+      
+      if(flags & BG_TRACK_SEEKABLE)
+        {
+        i = 0;
+        while(track->general_parameters[i].name)
+          {
+          if(!strcmp(track->general_parameters[i].name, "start_time") ||
+             !strcmp(track->general_parameters[i].name, "set_start_time"))
+            track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
+          i++;
+          }
+        }
+      }
+    
+    i = 0;
+    
+    while(track->general_parameters[i].name)
+      {
+      if(!strcmp(track->general_parameters[i].name, "name") ||
+         !strcmp(track->general_parameters[i].name, "set_end_time") ||
+         !strcmp(track->general_parameters[i].name, "end_time"))
+        track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
+    
+      if(!strcmp(track->general_parameters[i].name, "prefer_edl"))
+        track->general_parameters[i].flags |= BG_PARAMETER_HIDE_DIALOG;
+    
+      i++;
       }
     }
-  
-  i = 0;
-  
-  while(track->general_parameters[i].name)
-    {
-    if(!strcmp(track->general_parameters[i].name, "name") ||
-       !strcmp(track->general_parameters[i].name, "set_end_time") ||
-       !strcmp(track->general_parameters[i].name, "end_time"))
-      track->general_parameters[i].flags &= ~BG_PARAMETER_HIDE_DIALOG;
-    
-    if(!strcmp(track->general_parameters[i].name, "prefer_edl"))
-      track->general_parameters[i].flags |= BG_PARAMETER_HIDE_DIALOG;
-    
-    i++;
-    }
-  
-  track->metadata_parameters = bg_metadata_get_parameters((bg_metadata_t*)0);
+
+  if(!track->metadata_parameters)
+    track->metadata_parameters = bg_metadata_get_parameters((bg_metadata_t*)0);
   
   create_subtitle_parameters(track);
 
@@ -548,6 +553,7 @@ static void set_track(bg_transcoder_track_t * track,
   
   /* General parameters */
 
+  
   track->general_parameters = bg_parameter_info_copy_array(parameters_general);
 
   i = 0;
@@ -648,16 +654,16 @@ static void set_track(bg_transcoder_track_t * track,
       }
     i++;
     }
-
+  
   /* Stop here for redirectors */
 
   if(track->url)
     return;
   
   /* Metadata */
-    
+  
   track->metadata_parameters =
-    bg_metadata_get_parameters(&(track_info->metadata));
+    bg_metadata_get_parameters(&track_info->metadata);
 
   /* Chapter list */
   if(track_info->chapter_list)
@@ -1312,9 +1318,13 @@ static const bg_parameter_info_t general_parameters_video[] =
       .name =        "action",
       .long_name =   TRS("Action"),
       .type =        BG_PARAMETER_STRINGLIST,
-      .multi_names = (char const *[]){ "transcode", "forget", (char*)0 },
-      .multi_labels =  (char const *[]){ TRS("Transcode"), TRS("Forget"), (char*)0 },
+      .multi_names = (char const *[]){ "transcode", "copy", "forget", (char*)0 },
+      .multi_labels =  (char const *[]){ TRS("Transcode"),
+                                         TRS("Copy (if possible)"),
+                                         TRS("Forget"), (char*)0 },
       .val_default = { .val_str = "transcode" },
+      .help_string = TRS("Choose the desired action for the stream. If copying is not possible, the stream will be transcoded"),
+
     },
     {
       .name =       "twopass",
@@ -1337,9 +1347,13 @@ static const bg_parameter_info_t general_parameters_audio[] =
       .name =        "action",
       .long_name =   TRS("Action"),
       .type =        BG_PARAMETER_STRINGLIST,
-      .multi_names = (char const *[]){ "transcode", "forget", (char*)0 },
-      .multi_labels =  (char const *[]){ TRS("Transcode"), TRS("Forget"), (char*)0 },
+
+      .multi_names = (char const *[]){ "transcode", "copy", "forget", (char*)0 },
+      .multi_labels =  (char const *[]){ TRS("Transcode"),
+                                         TRS("Copy (if possible)"),
+                                         TRS("Forget"), (char*)0 },
       .val_default = { .val_str = "transcode" },
+      .help_string = TRS("Choose the desired action for the stream. If copying is not possible, the stream will be transcoded"),
     },
     {
       .name =        "in_language",
@@ -1916,6 +1930,9 @@ void bg_transcoder_track_set_encoders(bg_transcoder_track_t * t,
     t->audio_encoder_section = bg_cfg_section_copy(s);
     clean_section(t->audio_encoder_section);
     }
+  //  else
+  //    fprintf(stderr, "Got no audio encoder section\n");
+
   bg_encoder_section_get_stream_config(plugin_reg,
                                        encoder_section,
                                        BG_STREAM_AUDIO,
@@ -1948,7 +1965,11 @@ void bg_transcoder_track_set_encoders(bg_transcoder_track_t * t,
     {
     t->video_encoder_section = bg_cfg_section_copy(s);
     clean_section(t->video_encoder_section);
+    //    fprintf(stderr, "Got video encoder section\n");
     }
+  //  else
+  //    fprintf(stderr, "Got no video encoder section\n");
+
   bg_encoder_section_get_stream_config(plugin_reg,
                                        encoder_section,
                                        BG_STREAM_VIDEO,
