@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -159,11 +159,18 @@ static void track_2_xml(bg_transcoder_track_t * track,
   section_2_xml(track->general_section, node);
   xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
 
-
+  node = xmlNewTextChild(xml_track, (xmlNsPtr)0, (xmlChar*)"GENERAL_PARAMS", NULL);
+  bg_parameters_2_xml(track->general_parameters, node);
+  xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
+  
   node = xmlNewTextChild(xml_track, (xmlNsPtr)0, (xmlChar*)"METADATA", NULL);
   section_2_xml(track->metadata_section, node);
   xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
 
+  node = xmlNewTextChild(xml_track, (xmlNsPtr)0, (xmlChar*)"METADATA_PARAMS", NULL);
+  bg_parameters_2_xml(track->metadata_parameters, node);
+  xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
+  
   if(track->chapter_list)
     {
     node =
@@ -216,7 +223,7 @@ static void track_2_xml(bg_transcoder_track_t * track,
       stream_node = xmlNewTextChild(node, (xmlNsPtr)0, (xmlChar*)"STREAM", NULL);
       xmlAddChild(stream_node, BG_XML_NEW_TEXT("\n"));
 
-      audio_stream_2_xml(stream_node, &(track->audio_streams[i]));
+      audio_stream_2_xml(stream_node, &track->audio_streams[i]);
       xmlAddChild(node, BG_XML_NEW_TEXT("\n"));
       }
     xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
@@ -232,7 +239,7 @@ static void track_2_xml(bg_transcoder_track_t * track,
       {
       stream_node = xmlNewTextChild(node, (xmlNsPtr)0, (xmlChar*)"STREAM", NULL);
       xmlAddChild(stream_node, BG_XML_NEW_TEXT("\n"));
-      video_stream_2_xml(stream_node, &(track->video_streams[i]));
+      video_stream_2_xml(stream_node, &track->video_streams[i]);
       xmlAddChild(node, BG_XML_NEW_TEXT("\n"));
       }
     xmlAddChild(xml_track, BG_XML_NEW_TEXT("\n"));
@@ -246,7 +253,7 @@ static void track_2_xml(bg_transcoder_track_t * track,
       {
       stream_node = xmlNewTextChild(node, (xmlNsPtr)0, (xmlChar*)"STREAM", NULL);
       xmlAddChild(stream_node, BG_XML_NEW_TEXT("\n"));
-      subtitle_text_stream_2_xml(stream_node, &(track->subtitle_text_streams[i]));
+      subtitle_text_stream_2_xml(stream_node, &track->subtitle_text_streams[i]);
       xmlAddChild(node, BG_XML_NEW_TEXT("\n"));
       }
     }
@@ -259,7 +266,7 @@ static void track_2_xml(bg_transcoder_track_t * track,
       {
       stream_node = xmlNewTextChild(node, (xmlNsPtr)0, (xmlChar*)"STREAM", NULL);
       xmlAddChild(stream_node, BG_XML_NEW_TEXT("\n"));
-      subtitle_overlay_stream_2_xml(stream_node, &(track->subtitle_overlay_streams[i]));
+      subtitle_overlay_stream_2_xml(stream_node, &track->subtitle_overlay_streams[i]);
       xmlAddChild(node, BG_XML_NEW_TEXT("\n"));
       }
     }
@@ -590,37 +597,25 @@ static int xml_2_track(bg_transcoder_track_t * t,
       continue;
       }
     if(!BG_XML_STRCMP(node->name, "GENERAL"))
-      {
       t->general_section = xml_2_section(xml_doc, node);
-      }
+    else if(!BG_XML_STRCMP(node->name, "GENERAL_PARAMS"))
+      t->general_parameters = bg_xml_2_parameters(xml_doc, node);
     else if(!BG_XML_STRCMP(node->name, "METADATA"))
-      {
       t->metadata_section = xml_2_section(xml_doc, node);
-      }
+    else if(!BG_XML_STRCMP(node->name, "METADATA_PARAMS"))
+      t->metadata_parameters = bg_xml_2_parameters(xml_doc, node);
     else if(!BG_XML_STRCMP(node->name, "CHAPTERS"))
-      {
       t->chapter_list = bg_xml_2_chapter_list(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "INPUT"))
-      {
       t->input_section = xml_2_section(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "AUDIO_ENCODER"))
-      {
       t->audio_encoder_section = xml_2_section(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "VIDEO_ENCODER"))
-      {
       t->video_encoder_section = xml_2_section(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "SUBTITLE_TEXT_ENCODER"))
-      {
       t->subtitle_text_encoder_section = xml_2_section(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "SUBTITLE_OVERLAY_ENCODER"))
-      {
       t->subtitle_overlay_encoder_section = xml_2_section(xml_doc, node);
-      }
     else if(!BG_XML_STRCMP(node->name, "AUDIO_STREAMS"))
       {
       /* Count streams */
@@ -649,7 +644,7 @@ static int xml_2_track(bg_transcoder_track_t * t,
         {
         if(child_node->name && !BG_XML_STRCMP(child_node->name, "STREAM"))
           {
-          xml_2_audio(&(t->audio_streams[i]), xml_doc, child_node);
+          xml_2_audio(&t->audio_streams[i], xml_doc, child_node);
           i++;
           }
         child_node = child_node->next;
@@ -685,7 +680,7 @@ static int xml_2_track(bg_transcoder_track_t * t,
         {
         if(child_node->name && !BG_XML_STRCMP(child_node->name, "STREAM"))
           {
-          xml_2_video(&(t->video_streams[i]), xml_doc, child_node);
+          xml_2_video(&t->video_streams[i], xml_doc, child_node);
           i++;
           }
         child_node = child_node->next;
@@ -723,7 +718,7 @@ static int xml_2_track(bg_transcoder_track_t * t,
         {
         if(child_node->name && !BG_XML_STRCMP(child_node->name, "STREAM"))
           {
-          xml_2_subtitle_text(&(t->subtitle_text_streams[i]), xml_doc, child_node);
+          xml_2_subtitle_text(&t->subtitle_text_streams[i], xml_doc, child_node);
           i++;
           }
         child_node = child_node->next;
@@ -760,7 +755,7 @@ static int xml_2_track(bg_transcoder_track_t * t,
         {
         if(child_node->name && !BG_XML_STRCMP(child_node->name, "STREAM"))
           {
-          xml_2_subtitle_overlay(&(t->subtitle_overlay_streams[i]), xml_doc, child_node);
+          xml_2_subtitle_overlay(&t->subtitle_overlay_streams[i], xml_doc, child_node);
           i++;
           }
         child_node = child_node->next;
