@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -72,8 +72,8 @@ static audio_buffer_t * audio_buffer_create()
   audio_buffer_t * ret;
   ret = calloc(1, sizeof(*ret));
   ret->cnv = gavl_audio_converter_create();
-  pthread_mutex_init(&(ret->in_mutex),(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&(ret->gain_mutex),(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->in_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->gain_mutex,(pthread_mutexattr_t *)0);
   
   ret->gain_control = gavl_volume_control_create();
   
@@ -147,6 +147,7 @@ static void audio_buffer_put(audio_buffer_t * b,
                              const gavl_audio_frame_t * f)
   {
   pthread_mutex_lock(&b->in_mutex);
+  
   b->in_frame_1->valid_samples =
     gavl_audio_frame_copy(&b->in_format,
                           b->in_frame_1,
@@ -281,7 +282,7 @@ typedef struct
   
   } bg_visualizer_slave_t;
 
-static void init_plugin(bg_visualizer_slave_t * v);
+static int init_plugin(bg_visualizer_slave_t * v);
 
 static bg_plugin_handle_t *
 load_plugin_gmerlin(const char * filename)
@@ -448,11 +449,11 @@ bg_visualizer_slave_create(int argc, char ** argv)
   
   ret->cb_queue = bg_msg_queue_create();
   
-  pthread_mutex_init(&(ret->stop_mutex),(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&(ret->running_mutex),(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&(ret->vis_mutex),(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&(ret->ov_mutex),(pthread_mutexattr_t *)0);
-  pthread_mutex_init(&(ret->fps_mutex),(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->stop_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->running_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->vis_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->ov_mutex,(pthread_mutexattr_t *)0);
+  pthread_mutex_init(&ret->fps_mutex,(pthread_mutexattr_t *)0);
   
   ret->timer = gavl_timer_create();
 
@@ -519,7 +520,7 @@ static void uload_plugin(bg_plugin_handle_t * h, bg_plugin_api_t api)
 
 static void bg_visualizer_slave_destroy(bg_visualizer_slave_t * v)
   {
-  pthread_mutex_destroy(&(v->stop_mutex));
+  pthread_mutex_destroy(&v->stop_mutex);
 
   if(v->video_cnv)
     gavl_video_converter_destroy(v->video_cnv);
@@ -529,11 +530,11 @@ static void bg_visualizer_slave_destroy(bg_visualizer_slave_t * v)
 
   bg_msg_queue_destroy(v->cb_queue);
   
-  pthread_mutex_destroy(&(v->running_mutex));
-  pthread_mutex_destroy(&(v->fps_mutex));
-  pthread_mutex_destroy(&(v->stop_mutex));
-  pthread_mutex_destroy(&(v->ov_mutex));
-  pthread_mutex_destroy(&(v->vis_mutex));
+  pthread_mutex_destroy(&v->running_mutex);
+  pthread_mutex_destroy(&v->fps_mutex);
+  pthread_mutex_destroy(&v->stop_mutex);
+  pthread_mutex_destroy(&v->ov_mutex);
+  pthread_mutex_destroy(&v->vis_mutex);
 
   /* Close vis plugin */
   v->vis_plugin->close(v->vis_handle->priv);
@@ -694,7 +695,7 @@ static int bg_visualizer_slave_start(bg_visualizer_slave_t * v)
   gavl_timer_set(v->timer, 0);
   gavl_timer_start(v->timer);
   
-  pthread_create(&(v->video_thread), (pthread_attr_t*)0, video_thread_func, v);
+  pthread_create(&v->video_thread, (pthread_attr_t*)0, video_thread_func, v);
   bg_log(BG_LOG_INFO, LOG_DOMAIN, "Started thread");
   return 1;
   }
@@ -720,7 +721,7 @@ static void cleanup_plugin(bg_visualizer_slave_t * v)
   {
   }
 
-static void init_plugin(bg_visualizer_slave_t * v)
+static int init_plugin(bg_visualizer_slave_t * v)
   {
   gavl_audio_format_copy(&v->audio_format_out, &v->audio_format_in);
 
@@ -741,7 +742,8 @@ static void init_plugin(bg_visualizer_slave_t * v)
     gavl_video_format_copy(&v->video_format_out, &v->video_format_in_real);
     
     /* Open OV Plugin */
-    v->ov_plugin->open(v->ov_handle->priv, &v->video_format_out, 0);
+    if(!v->ov_plugin->open(v->ov_handle->priv, &v->video_format_out, 0))
+      return 0;
     
     /* Initialize video converter */
     
@@ -759,14 +761,14 @@ static void init_plugin(bg_visualizer_slave_t * v)
     }
   else
     {
-    v->vis_plugin->open_win(v->vis_handle->priv, &v->audio_format_out,
-                            v->window_id);
-    
+    if(!v->vis_plugin->open_win(v->vis_handle->priv, &v->audio_format_out,
+                                v->window_id))
+      return 0;
     gavl_video_format_copy(&v->video_format_out, &v->video_format_in);
     }
   
   audio_buffer_init(v->audio_buffer, &v->audio_format_in, &v->audio_format_out);
-
+  return 1;
   }
 
 
@@ -780,12 +782,21 @@ static int msg_write_callback(void * priv, const uint8_t * data, int len)
   return write(STDOUT_FILENO, data, len);
   }
 
+static int write_message(msg)
+  {
+  int result;
+//  fprintf(stderr, "Write message slave...\n");
+  result = bg_msg_write(msg, msg_write_callback, NULL);
+//  fprintf(stderr, "Write message slave done %d\n", result);
+  return result;
+  }
+
 static void flush_queue(bg_msg_queue_t * queue)
   {
   bg_msg_t * msg;
   while((msg = bg_msg_queue_try_lock_read(queue)))
     {
-    bg_msg_write(msg, msg_write_callback, NULL);
+    write_message(msg);
     bg_msg_queue_unlock_read(queue);
     }
   }
@@ -808,7 +819,8 @@ int main(int argc, char ** argv)
   bg_parameter_type_t parameter_type;
   gavl_dsp_context_t * ctx;
   int big_endian;
-  
+  int result;
+
   ctx = gavl_dsp_context_create();
   
   memset(&parameter_value, 0, sizeof(parameter_value));
@@ -830,8 +842,10 @@ int main(int argc, char ** argv)
   
   while(keep_going)
     {
-    
-    if(!bg_msg_read(msg, msg_read_callback, (void*)0))
+//    fprintf(stderr, "Read message slave...\n"); 
+    result = bg_msg_read(msg, msg_read_callback, (void*)0);
+//    fprintf(stderr, "Read message slave done %d\n", result);
+    if(!result)
       break;
     
     switch(bg_msg_get_id(msg))
@@ -851,8 +865,15 @@ int main(int argc, char ** argv)
                                 audio_frame,
                                 msg_read_callback,
                                 (void*)0, big_endian);
-        audio_buffer_put(s->audio_buffer,
-                         audio_frame);
+        
+        if(!pthread_mutex_trylock(&s->running_mutex))
+          {
+          pthread_mutex_unlock(&s->running_mutex);
+          break;
+          }
+        else
+          audio_buffer_put(s->audio_buffer,
+                           audio_frame);
         break;
       case BG_VIS_MSG_VIS_PARAM:
         bg_msg_get_parameter(msg,
@@ -915,8 +936,10 @@ int main(int argc, char ** argv)
           s->video_format_in.image_height;
         break;
       case BG_VIS_MSG_START:
-        init_plugin(s);
-        bg_visualizer_slave_start(s);
+        if(!init_plugin(s))
+          bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Starting visualization failed");
+        else
+          bg_visualizer_slave_start(s);
         break;
       case BG_VIS_MSG_QUIT:
         keep_going = 0;
@@ -932,15 +955,13 @@ int main(int argc, char ** argv)
           pthread_mutex_lock(&s->fps_mutex);
           bg_msg_set_arg_float(msg, 0, s->fps);
           pthread_mutex_unlock(&s->fps_mutex);
-          bg_msg_write(msg, msg_write_callback,
-                       NULL);
+          write_message(msg);
           bg_msg_free(msg);
           
           }
         counter++;
         bg_msg_set_id(msg, BG_VIS_SLAVE_MSG_END);
-        bg_msg_write(msg, msg_write_callback,
-                     NULL);
+        write_message(msg);
         bg_msg_free(msg);
         break;
       }
