@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -54,6 +54,10 @@ static int has_extension(const char * extensions,
   {
   int len;
   const char * pos;
+
+  if(!extensions)
+    return 0;
+  
   len = strlen(name);
   while(1)
     {
@@ -67,16 +71,16 @@ static int has_extension(const char * extensions,
   return 0;
   }
 
-static void check_gl(bg_x11_window_t * win,
-                     gavl_pixelformat_t * formats_ret,
-                     gl_priv_t * priv)
+static int check_gl(bg_x11_window_t * win,
+                    gavl_pixelformat_t * formats_ret,
+                    gl_priv_t * priv)
   {
   int format_index = 0;
     
   if(!win->gl_fbconfigs)
     {
     formats_ret[0] = GAVL_PIXELFORMAT_NONE;
-    return;
+    return 0;
     }
   formats_ret[format_index++] = GAVL_RGB_24;
   formats_ret[format_index++] = GAVL_RGBA_32;
@@ -93,7 +97,7 @@ static void check_gl(bg_x11_window_t * win,
   formats_ret[format_index++] = GAVL_GRAYA_FLOAT;
   formats_ret[format_index] = GAVL_PIXELFORMAT_NONE;
   
-  return;
+  return 1;
   }
 
 static int init_gl(driver_data_t * d)
@@ -103,9 +107,8 @@ static int init_gl(driver_data_t * d)
   d->priv = priv;
   
   d->pixelformats = malloc(13*sizeof(*d->pixelformats));
-  check_gl(d->win, d->pixelformats, priv);
   
-  return 1;
+  return check_gl(d->win, d->pixelformats, priv);
   }
 
 static void create_texture(gl_priv_t * priv,
