@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -749,6 +749,13 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
         }
       break;
     case MotionNotify:
+
+      /* Check if we had a fake motion event from the screensaver */
+      if(w->scr.fake_motion)
+        {
+        w->scr.fake_motion--;
+        return;
+        }
       
       w->idle_counter = 0;
       if(w->pointer_hidden)
@@ -831,7 +838,7 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
       break;
     case KeyPress:
     case KeyRelease:
-      XLookupString(&(evt->xkey), &key_char, 1, &keysym, NULL);
+      XLookupString(&evt->xkey, &key_char, 1, &keysym, NULL);
       evt->xkey.state &= STATE_IGNORE;
       
       if((evt->xkey.window == w->normal.win) ||
