@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -434,7 +434,7 @@ static int open_display(bg_x11_window_t * w)
   if (XineramaQueryExtension(w->dpy,&foo,&bar) &&
       XineramaIsActive(w->dpy))
     {
-    w->xinerama = XineramaQueryScreens(w->dpy,&(w->nxinerama));
+    w->xinerama = XineramaQueryScreens(w->dpy,&w->nxinerama);
     }
 #endif
 
@@ -748,9 +748,8 @@ static int create_window(bg_x11_window_t * w,
       set_min_size(w, w->normal.win, w->min_width, w->min_height);
 
     w->normal.toplevel = w->normal.win;
-    
-    w->normal.focus_child =
-      w->normal.focus_child = XCreateSimpleWindow(w->dpy, w->normal.win,
+
+    w->normal.focus_child = XCreateSimpleWindow(w->dpy, w->normal.win,
                                                   -1, -1, 1, 1, 0,
                                                   0, 0);
     XSelectInput(w->dpy, w->normal.focus_child,
