@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -171,7 +171,7 @@ static void * create_alsa()
   
   for(i = 0; i < num_global_parameters; i++)
     {
-    bg_parameter_info_copy(&(ret->parameters[i+1]), &global_parameters[i]);
+    bg_parameter_info_copy(&ret->parameters[i+1], &global_parameters[i]);
     }
   
   return ret;
@@ -325,7 +325,7 @@ static int open_alsa(void * data, gavl_audio_format_t * format)
   
   if(!priv->pcm)
     return 0;
-  gavl_audio_format_copy(&(priv->format), format);
+  gavl_audio_format_copy(&priv->format, format);
   return 1;
   }
 
