@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -365,6 +365,12 @@ static int read_image_bmp(void *priv, gavl_video_frame_t *frame)
   unsigned short x, y, i, width, skip;
 
   /* read file to header */
+
+  if(!frame)
+    {
+    fclose(p->bmp_file);
+    return 1;
+    }
   
   fseek(p->bmp_file, p->offset, SEEK_SET);
 
