@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -83,7 +83,6 @@ typedef struct
     {
     gavl_audio_format_t format;
     lqt_codec_info_t ** codec_info;
-    char language[4];
     int64_t samples_written;
     } * audio_streams;
   
@@ -157,7 +156,7 @@ static int open_lqt(void * data, const char * filename,
                     const bg_chapter_list_t * chapter_list)
   {
   char * track_string;
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   e->filename = bg_filename_ensure_extension(filename, get_extension(e->file_type));
 
@@ -219,36 +218,75 @@ static int open_lqt(void * data, const char * filename,
   return 1;
   }
 
+static int writes_compressed_audio_lqt(void * data,
+                                       const gavl_audio_format_t * format,
+                                       const gavl_compression_info_t * ci)
+  {
+  e_lqt_t * e = data;
+  return lqt_gavl_writes_compressed_audio(e->file_type, format, ci);
+  }
+
+static int writes_compressed_video_lqt(void * data,
+                                       const gavl_video_format_t * format,
+                                       const gavl_compression_info_t * ci)
+  {
+  e_lqt_t * e = data;
+
+  fprintf(stderr, "writes_compressed_video_lqt\n");
+  gavl_video_format_dump(format);
+
+  return lqt_gavl_writes_compressed_video(e->file_type, format, ci);
+  }
+
+
+
 static int add_audio_stream_lqt(void * data, const char * language,
                                 const gavl_audio_format_t * format)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   e->audio_streams =
     realloc(e->audio_streams,
             (e->num_audio_streams+1)*sizeof(*(e->audio_streams)));
-  memset(&(e->audio_streams[e->num_audio_streams]), 0,
+  memset(&e->audio_streams[e->num_audio_streams], 0,
          sizeof(*(e->audio_streams)));
-  gavl_audio_format_copy(&(e->audio_streams[e->num_audio_streams].format),
+  gavl_audio_format_copy(&e->audio_streams[e->num_audio_streams].format,
                          format);
-
-  strncpy(e->audio_streams[e->num_audio_streams].language,
-          language, 3);
   
+  lqt_gavl_add_audio_track(e->file, &e->audio_streams[e->num_audio_streams].format,
+                           NULL);
+  lqt_set_audio_language(e->file, e->num_audio_streams, language);
+  
+  e->num_audio_streams++;
+  return e->num_audio_streams-1;
+  }
+
+static int add_audio_stream_compressed_lqt(void * data, const char * language,
+                                           const gavl_audio_format_t * format,
+                                           const gavl_compression_info_t * ci)
+  {
+  e_lqt_t * e = data;
+
+  e->audio_streams =
+    realloc(e->audio_streams,
+            (e->num_audio_streams+1)*sizeof(*(e->audio_streams)));
+  memset(&e->audio_streams[e->num_audio_streams], 0,
+         sizeof(*(e->audio_streams)));
+  lqt_gavl_add_audio_track_compressed(e->file, format, ci);
   e->num_audio_streams++;
   return e->num_audio_streams-1;
   }
 
 static int add_subtitle_text_stream_lqt(void * data, const char * language, int * timescale)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   e->subtitle_text_streams =
     realloc(e->subtitle_text_streams,
             (e->num_subtitle_text_streams+1)*
             sizeof(*(e->subtitle_text_streams)));
 
-  memset(&(e->subtitle_text_streams[e->num_subtitle_text_streams]), 0,
+  memset(&e->subtitle_text_streams[e->num_subtitle_text_streams], 0,
          sizeof(*(e->subtitle_text_streams)));
 
   strncpy(e->subtitle_text_streams[e->num_subtitle_text_streams].language,
@@ -263,16 +301,37 @@ static int add_subtitle_text_stream_lqt(void * data, const char * language, int
 static int add_video_stream_lqt(void * data,
                                 const gavl_video_format_t* format)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   e->video_streams =
     realloc(e->video_streams,
             (e->num_video_streams+1)*sizeof(*(e->video_streams)));
-  memset(&(e->video_streams[e->num_video_streams]), 0,
+  memset(&e->video_streams[e->num_video_streams], 0,
          sizeof(*(e->video_streams)));
   
-  gavl_video_format_copy(&(e->video_streams[e->num_video_streams].format),
+  gavl_video_format_copy(&e->video_streams[e->num_video_streams].format,
                          format);
+
+  lqt_gavl_add_video_track(e->file, &e->video_streams[e->num_video_streams].format,
+                           NULL);
+
+  e->num_video_streams++;
+  return e->num_video_streams-1;
+  }
+
+static int add_video_stream_compressed_lqt(void * data,
+                                           const gavl_video_format_t* format,
+                                           const gavl_compression_info_t * ci)
+  {
+  e_lqt_t * e = data;
+
+  e->video_streams =
+    realloc(e->video_streams,
+            (e->num_video_streams+1)*sizeof(*(e->video_streams)));
+  memset(&e->video_streams[e->num_video_streams], 0,
+         sizeof(*(e->video_streams)));
+  
+  lqt_gavl_add_video_track_compressed(e->file, format, ci);
   
   e->num_video_streams++;
   return e->num_video_streams-1;
@@ -281,23 +340,23 @@ static int add_video_stream_lqt(void * data,
 static void get_audio_format_lqt(void * data, int stream,
                                  gavl_audio_format_t * ret)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
-  gavl_audio_format_copy(ret, &(e->audio_streams[stream].format));
+  gavl_audio_format_copy(ret, &e->audio_streams[stream].format);
   
   }
   
 static void get_video_format_lqt(void * data, int stream,
                                  gavl_video_format_t * ret)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
-  gavl_video_format_copy(ret, &(e->video_streams[stream].format));
+  e_lqt_t * e = data;
+  gavl_video_format_copy(ret, &e->video_streams[stream].format);
   }
 
 static int start_lqt(void * data)
   {
   int i, tmp;
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   for(i = 0; i < e->num_audio_streams; i++)
     {
@@ -305,14 +364,14 @@ static int start_lqt(void * data)
     tmp = e->audio_streams[i].format.samples_per_frame;
     lqt_gavl_get_audio_format(e->file,
                               i,
-                              &(e->audio_streams[i].format));
+                              &e->audio_streams[i].format);
     e->audio_streams[i].format.samples_per_frame = tmp;
     }
   for(i = 0; i < e->num_video_streams; i++)
     {
     lqt_gavl_get_video_format(e->file,
                               i,
-                              &(e->video_streams[i].format), 1);
+                              &e->video_streams[i].format, 1);
     }
 
   if(!(e->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML)))
@@ -374,7 +433,7 @@ static int write_audio_frame_lqt(void * data, gavl_audio_frame_t* frame,
                                  int stream)
   {
   gavl_time_t test_time;
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   e->audio_streams[stream].samples_written += frame->valid_samples;
   
@@ -391,7 +450,7 @@ static int write_video_frame_lqt(void * data, gavl_video_frame_t* frame,
                                   int stream)
   {
   gavl_time_t test_time;
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   
   test_time = gavl_time_unscale(e->video_streams[stream].format.timescale,
                                 frame->timestamp);
@@ -406,7 +465,7 @@ static int write_subtitle_text_lqt(void * data,const char * text,
                                    int64_t start,
                                    int64_t duration, int stream)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   if(e->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML))
     {
@@ -439,7 +498,7 @@ static int close_lqt(void * data, int do_delete)
   int i;
   gavl_time_t chapter_time;
   int num_chapters;
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   
   if(!e->file)
     return 1;
@@ -543,7 +602,7 @@ static int close_lqt(void * data, int do_delete)
 
 static void destroy_lqt(void * data)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
 
   close_lqt(data, 1);
   
@@ -560,9 +619,9 @@ static void create_parameters(e_lqt_t * e)
   e->audio_parameters = bg_parameter_info_copy_array(audio_parameters);
   e->video_parameters = bg_parameter_info_copy_array(video_parameters);
   
-  bg_lqt_create_codec_info(&(e->audio_parameters[0]),
+  bg_lqt_create_codec_info(&e->audio_parameters[0],
                            1, 0, 1, 0);
-  bg_lqt_create_codec_info(&(e->video_parameters[2]),
+  bg_lqt_create_codec_info(&e->video_parameters[2],
                            0, 1, 1, 0);
   
   }
@@ -604,7 +663,7 @@ static const bg_parameter_info_t * get_parameters_lqt(void * data)
 static void set_parameter_lqt(void * data, const char * name,
                               const bg_parameter_value_t * val)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   if(!name)
     return;
 
@@ -632,7 +691,7 @@ static void set_parameter_lqt(void * data, const char * name,
 
 static const bg_parameter_info_t * get_audio_parameters_lqt(void * data)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   
   if(!e->audio_parameters)
     create_parameters(e);
@@ -642,7 +701,7 @@ static const bg_parameter_info_t * get_audio_parameters_lqt(void * data)
 
 static const bg_parameter_info_t * get_video_parameters_lqt(void * data)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   
   if(!e->video_parameters)
     create_parameters(e);
@@ -653,7 +712,7 @@ static const bg_parameter_info_t * get_video_parameters_lqt(void * data)
 static void set_audio_parameter_lqt(void * data, int stream, const char * name,
                                     const bg_parameter_value_t * val)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
     
   if(!name)
     return;
@@ -665,13 +724,12 @@ static void set_audio_parameter_lqt(void * data, int stream, const char * name,
     e->audio_streams[stream].codec_info =
       lqt_find_audio_codec_by_name(val->val_str);
     
-    lqt_gavl_add_audio_track(e->file, &e->audio_streams[stream].format,
+    lqt_gavl_set_audio_codec(e->file, stream,
+                             &e->audio_streams[stream].format,
                              *e->audio_streams[stream].codec_info);
-    lqt_set_audio_language(e->file, stream, e->audio_streams[stream].language);
     }
   else
     {
-
     bg_lqt_set_audio_parameter(e->file,
                                stream,
                                name,
@@ -687,14 +745,16 @@ static void set_audio_parameter_lqt(void * data, int stream, const char * name,
 static int set_video_pass_lqt(void * data, int stream, int pass,
                               int total_passes, const char * stats_file)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   return lqt_set_video_pass(e->file, pass, total_passes, stats_file, stream);
   }
 
+
+
 static void set_video_parameter_lqt(void * data, int stream, const char * name,
                                     const bg_parameter_value_t * val)
   {
-  e_lqt_t * e = (e_lqt_t*)data;
+  e_lqt_t * e = data;
   
   if(!name)
     return;
@@ -717,7 +777,7 @@ static void set_video_parameter_lqt(void * data, int stream, const char * name,
                                &e->video_streams[stream].format);
       }
     
-    lqt_gavl_add_video_track(e->file, &e->video_streams[stream].format,
+    lqt_gavl_set_video_codec(e->file, stream, &e->video_streams[stream].format,
                              *e->video_streams[stream].codec_info);
     
     e->video_streams[stream].rows = lqt_gavl_rows_create(e->file, stream);
@@ -734,6 +794,19 @@ static void set_video_parameter_lqt(void * data, int stream, const char * name,
     }
   }
 
+static int write_video_packet_lqt(void * data, gavl_packet_t * p, int stream)
+  {
+  e_lqt_t * e = data;
+  return lqt_gavl_write_video_packet(e->file, stream, p);
+  }
+
+static int write_audio_packet_lqt(void * data, gavl_packet_t * p, int stream)
+  {
+  e_lqt_t * e = data;
+  return lqt_gavl_write_audio_packet(e->file, stream, p);
+  }
+
+
 /* Subtitle parameters */
 
 static const bg_parameter_info_t subtitle_text_parameters[] =
@@ -790,7 +863,7 @@ static void set_subtitle_text_parameter_lqt(void * priv, int stream,
                                             const char * name,
                                             const bg_parameter_value_t * val)
   {
-  e_lqt_t * e = (e_lqt_t*)priv;
+  e_lqt_t * e = priv;
   
   if(!name)
     return;
@@ -851,11 +924,16 @@ like H.264/AVC, AAC, MP3, Divx compatible etc. Also supported are chapters and t
 
     .open =                 open_lqt,
 
+    .writes_compressed_audio = writes_compressed_audio_lqt,
+    .writes_compressed_video = writes_compressed_video_lqt,
+    
     .add_audio_stream =     add_audio_stream_lqt,
+    .add_audio_stream_compressed =     add_audio_stream_compressed_lqt,
     
     .add_subtitle_text_stream = add_subtitle_text_stream_lqt,
 
     .add_video_stream =     add_video_stream_lqt,
+    .add_video_stream_compressed =     add_video_stream_compressed_lqt,
     .set_video_pass =       set_video_pass_lqt,
     
     .set_audio_parameter =          set_audio_parameter_lqt,
@@ -869,6 +947,10 @@ like H.264/AVC, AAC, MP3, Divx compatible etc. Also supported are chapters and t
     
     .write_audio_frame =    write_audio_frame_lqt,
     .write_video_frame =    write_video_frame_lqt,
+
+    .write_audio_packet = write_audio_packet_lqt,
+    .write_video_packet = write_video_packet_lqt,
+    
     .write_subtitle_text =  write_subtitle_text_lqt,
     .close =                close_lqt,
   };
