@@ -1,7 +1,7 @@
 /*****************************************************************
  * lqtgavl - gavl Bindings for libquicktime
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -20,6 +20,8 @@
  * *****************************************************************/
 
 #include <stdlib.h>
+#include <string.h>
+
 #include <lqtgavl.h>
 #include <colormodels.h>
 #include <lqt_version.h>
@@ -255,19 +257,17 @@ static uint32_t timecode_flags_gavl_2_lqt(int gavl)
 
 /* Audio encoding */
 
-void lqt_gavl_add_audio_track(quicktime_t * file,
-                               gavl_audio_format_t * format,
-                               lqt_codec_info_t * codec)
+void lqt_gavl_set_audio_codec(quicktime_t * file,
+                              int track,
+                              gavl_audio_format_t * format,
+                              lqt_codec_info_t * codec)
   {
   int i;
   const lqt_channel_t * chans_1;
   lqt_channel_t * chans_2;
-  
-  int track = quicktime_audio_tracks(file);
-  
-  lqt_add_audio_track(file, format->num_channels, format->samplerate,
-                      16, codec);
 
+  lqt_set_audio_codec(file, track, codec);
+  
   format->sample_format =
     sampleformat_lqt_2_gavl(lqt_get_sample_format(file, track));
   format->interleave_mode = GAVL_INTERLEAVE_ALL;
@@ -297,20 +297,28 @@ void lqt_gavl_add_audio_track(quicktime_t * file,
     }
   }
 
-void lqt_gavl_add_video_track(quicktime_t * file,
-                               gavl_video_format_t * format,
+
+void lqt_gavl_add_audio_track(quicktime_t * file,
+                               gavl_audio_format_t * format,
                                lqt_codec_info_t * codec)
   {
-  int track = quicktime_video_tracks(file);
-
   
-  lqt_add_video_track(file, format->image_width, format->image_height,
-                      format->frame_duration, format->timescale,
-                      codec);
-  lqt_set_pixel_aspect(file, track, format->pixel_width, format->pixel_height);
-  lqt_set_interlace_mode(file, track,
-                         interlace_mode_gavl_2_lqt(format->interlace_mode));
+  int track = quicktime_audio_tracks(file);
+  
+  lqt_add_audio_track(file, format->num_channels, format->samplerate,
+                      16, NULL);
 
+  if(codec)
+    lqt_gavl_set_audio_codec(file, track, format, codec);
+  }
+
+void lqt_gavl_set_video_codec(quicktime_t * file,
+                              int track,
+                              gavl_video_format_t * format,
+                              lqt_codec_info_t * codec)
+  {
+  lqt_set_video_codec(file, track, codec);
+  
 #if LQT_BUILD < LQT_MAKE_BUILD(1,1,2)
   format->pixelformat = pixelformat_lqt_2_gavl(lqt_get_cmodel(file, track));
 #else
@@ -337,13 +345,33 @@ void lqt_gavl_add_video_track(quicktime_t * file,
   else
     format->pixelformat = pixelformat_lqt_2_gavl(lqt_get_cmodel(file, track));
 #endif
+  }
+
+void lqt_gavl_add_video_track(quicktime_t * file,
+                              gavl_video_format_t * format,
+                              lqt_codec_info_t * codec)
+  {
+  int track = quicktime_video_tracks(file);
   
+  if(lqt_add_video_track(file, format->image_width, format->image_height,
+                          format->frame_duration, format->timescale,
+                          NULL))
+    return;
+  lqt_set_pixel_aspect(file, track, format->pixel_width, format->pixel_height);
+  lqt_set_interlace_mode(file, track,
+                         interlace_mode_gavl_2_lqt(format->interlace_mode));
+
+  /* Add timecode track */
   if(format->timecode_format.int_framerate > 0)
     {
     lqt_add_timecode_track(file, track,
                            timecode_flags_gavl_2_lqt(format->timecode_format.flags),
                            format->timecode_format.int_framerate);
     }
+
+  if(codec)
+    lqt_gavl_set_video_codec(file, track, format, codec);
+  
   }
 
 int lqt_gavl_encode_video(quicktime_t * file, int track,
@@ -367,7 +395,6 @@ int lqt_gavl_encode_video(quicktime_t * file, int track,
                        gavl_timecode_to_framecount(&f, frame->timecode));
     
     }
-                       
   
   if(lqt_colormodel_is_planar(lqt_get_cmodel(file, track)))
     {
@@ -653,3 +680,393 @@ gavl_time_t lqt_gavl_duration(quicktime_t * file)
     }
   return ret;
   }
+
+/* Compression support */
+
+static int compression_info_gavl_2_lqt(const gavl_compression_info_t * gci,
+                                       const gavl_audio_format_t * afmt,
+                                       const gavl_video_format_t * vfmt,
+                                       lqt_compression_info_t * lci)
+  {
+  memset(lci, 0, sizeof(*lci));
+
+  /* Field pictures are not supported */
+  if(gci->flags & GAVL_COMPRESSION_HAS_FIELD_PICTURES)
+    return 0;
+  
+  switch(gci->id)
+    {
+    case GAVL_CODEC_ID_NONE: //!< Unknown/unsupported compression format
+      break;
+    /* Audio */
+    case GAVL_CODEC_ID_ALAW: //!< alaw 2:1
+      lci->id = LQT_COMPRESSION_ALAW;
+      break;
+    case GAVL_CODEC_ID_ULAW:    //!< mu-law 2:1
+      lci->id = LQT_COMPRESSION_ULAW;
+      break;
+    case GAVL_CODEC_ID_MP2:       //!< MPEG-1 audio layer II
+      lci->id = LQT_COMPRESSION_MP2;
+      break;
+    case GAVL_CODEC_ID_MP3:       //!< MPEG-1/2 audio layer 3 CBR/VBR
+      lci->id = LQT_COMPRESSION_MP3;
+      break;
+    case GAVL_CODEC_ID_AC3:       //!< AC3
+      lci->id = LQT_COMPRESSION_AC3;
+      break;
+    case GAVL_CODEC_ID_AAC:      //!< AAC as stored in quicktime/mp4
+      lci->id = LQT_COMPRESSION_AAC;
+      break;
+    case GAVL_CODEC_ID_VORBIS:    //!< Vorbis (segmented extradata and packets)
+      break;
+    
+    /* Video */
+    case GAVL_CODEC_ID_JPEG:      //!< JPEG image
+      lci->id = LQT_COMPRESSION_JPEG;
+      break;
+    case GAVL_CODEC_ID_PNG:       //!< PNG image
+      lci->id = LQT_COMPRESSION_PNG;
+      break;
+    case GAVL_CODEC_ID_TIFF:      //!< TIFF image
+      lci->id = LQT_COMPRESSION_TIFF;
+      break;
+    case GAVL_CODEC_ID_TGA:       //!< TGA image
+      lci->id = LQT_COMPRESSION_TGA;
+      break;
+    case GAVL_CODEC_ID_DV:       //!< DV
+      lci->id = LQT_COMPRESSION_DV;
+      break;
+    case GAVL_CODEC_ID_MPEG1:     //!< MPEG-1 video
+      break;
+    case GAVL_CODEC_ID_MPEG2:     //!< MPEG-2 video
+      /* Check for D10 */
+
+      if(!(gci->flags & (GAVL_COMPRESSION_HAS_P_FRAMES|GAVL_COMPRESSION_HAS_B_FRAMES)) &&
+         ((gci->bitrate == 30000000) ||
+          (gci->bitrate == 40000000) ||
+          (gci->bitrate == 50000000)) &&
+         vfmt &&
+         (vfmt->pixelformat == GAVL_YUV_422_P) &&
+         (vfmt->image_width == 720) &&
+         ((vfmt->image_height == 576) ||
+          (vfmt->image_height == 608) ||
+          (vfmt->image_height == 486) ||
+          (vfmt->image_height == 512)))
+        {
+        lci->id = LQT_COMPRESSION_D10;
+        }
+      
+      break;
+    case GAVL_CODEC_ID_MPEG4_ASP: //!< MPEG-4 ASP (a.k.a. Divx4)
+      lci->id = LQT_COMPRESSION_MPEG4_ASP;
+      break;
+    case GAVL_CODEC_ID_H264:      //!< H.264 (Annex B)
+      lci->id = LQT_COMPRESSION_H264;
+      break;
+    case GAVL_CODEC_ID_THEORA:    //!< Theora (segmented extradata
+      break;
+    case GAVL_CODEC_ID_DIRAC:     //!< Complete DIRAC frames, sequence end code 
+      lci->id = LQT_COMPRESSION_DIRAC;
+      break;
+    }
+
+  if(lci->id == LQT_COMPRESSION_NONE)
+    return 0;
+
+  /* Set audio/video specific stuff */
+  if(lci->id < 0x10000)
+    {
+    if(!afmt)
+      return 0;
+
+    lci->samplerate = afmt->samplerate;
+    lci->num_channels = afmt->num_channels;
+    
+    }
+  else
+    {
+    if(!vfmt)
+      return 0;
+    lci->width           = vfmt->image_width;
+    lci->height          = vfmt->image_height;
+    lci->pixel_width     = vfmt->pixel_width;
+    lci->pixel_height    = vfmt->pixel_height;
+    lci->colormodel      = pixelformat_gavl_2_lqt(vfmt->pixelformat);
+    lci->video_timescale = vfmt->timescale;
+    }
+  /* Set generic stuff */
+  lci->bitrate = gci->bitrate;
+
+  if(gci->flags & GAVL_COMPRESSION_HAS_P_FRAMES)
+    lci->flags |= LQT_COMPRESSION_HAS_P_FRAMES;
+  if(gci->flags & GAVL_COMPRESSION_HAS_B_FRAMES)
+    lci->flags |= LQT_COMPRESSION_HAS_B_FRAMES;
+  if(gci->flags & GAVL_COMPRESSION_SBR)
+    lci->flags |= LQT_COMPRESSION_SBR;
+  
+  lci->global_header = gci->global_header;
+  lci->global_header_len = gci->global_header_len;
+  
+  return 1;
+  }
+
+static int compression_info_lqt_2_gavl(const lqt_compression_info_t * lci,
+                                       gavl_compression_info_t * gci)
+  {
+  switch(lci->id)
+    {
+    case LQT_COMPRESSION_ALAW:
+      gci->id = GAVL_CODEC_ID_ALAW;
+      break;
+    case LQT_COMPRESSION_ULAW:
+      gci->id = GAVL_CODEC_ID_ULAW;
+      break;
+    case LQT_COMPRESSION_MP2:
+      gci->id = GAVL_CODEC_ID_MP2;
+      break;
+    case LQT_COMPRESSION_MP3:
+      gci->id = GAVL_CODEC_ID_MP3;
+      break;
+    case LQT_COMPRESSION_AC3:
+      gci->id = GAVL_CODEC_ID_AC3;
+      break;
+    case LQT_COMPRESSION_AAC:
+      gci->id = GAVL_CODEC_ID_AAC;
+      break;
+
+    /* Video */
+    case LQT_COMPRESSION_JPEG: //!< JPEG image
+      gci->id = GAVL_CODEC_ID_JPEG;
+      break;
+    case LQT_COMPRESSION_PNG:            //!< PNG image
+      gci->id = GAVL_CODEC_ID_PNG;
+      break;
+    case LQT_COMPRESSION_TIFF:           //!< TIFF image
+      gci->id = GAVL_CODEC_ID_TIFF;
+      break;
+    case LQT_COMPRESSION_TGA:            //!< TGA image
+      gci->id = GAVL_CODEC_ID_TGA;
+      break;
+    case LQT_COMPRESSION_MPEG4_ASP:      //!< MPEG-4 ASP (a.k.a. Divx4)
+      gci->id = GAVL_CODEC_ID_MPEG4_ASP;
+      break;
+    case LQT_COMPRESSION_H264:           //!< H.264 (Annex B)
+      gci->id = GAVL_CODEC_ID_H264;
+      break;
+    case LQT_COMPRESSION_DIRAC:          //!< Complete DIRAC frames
+      gci->id = GAVL_CODEC_ID_DIRAC;
+      break;
+    case LQT_COMPRESSION_D10:            //!< D10 according to SMPTE 356M-2001
+      gci->id = GAVL_CODEC_ID_MPEG2;
+      break;
+    case LQT_COMPRESSION_DV:            //!< DV (multiple variants)
+      gci->id = GAVL_CODEC_ID_DV;
+      break;
+    case LQT_COMPRESSION_NONE:
+      break;
+    }
+
+  if(gci->id == GAVL_CODEC_ID_NONE)
+    return 0;
+  
+  gci->bitrate = lci->bitrate;
+  gci->global_header_len = lci->global_header_len;
+
+  if(gci->global_header_len)
+    {
+    gci->global_header = malloc(gci->global_header_len);
+    memcpy(gci->global_header, lci->global_header, gci->global_header_len);
+    }
+  
+  if(lci->flags & LQT_COMPRESSION_HAS_P_FRAMES)
+    gci->flags |= GAVL_COMPRESSION_HAS_P_FRAMES;
+  if(lci->flags & LQT_COMPRESSION_HAS_B_FRAMES)
+    gci->flags |= GAVL_COMPRESSION_HAS_B_FRAMES;
+  if(lci->flags & LQT_COMPRESSION_SBR)
+    gci->flags |= GAVL_COMPRESSION_SBR;
+  
+  return 1;
+  }
+  
+int lqt_gavl_get_audio_compression_info(quicktime_t * file, int track,
+                                        gavl_compression_info_t * ci)
+  {
+  const lqt_compression_info_t * lci;
+  lci = lqt_get_audio_compression_info(file, track);
+  if(lci)
+    {
+    return compression_info_lqt_2_gavl(lci, ci);
+    }
+  return 0;
+  }
+
+
+int lqt_gavl_get_video_compression_info(quicktime_t * file, int track,
+                                        gavl_compression_info_t * ci)
+  {
+  const lqt_compression_info_t * lci;
+  lci = lqt_get_video_compression_info(file, track);
+  if(lci)
+    {
+    return compression_info_lqt_2_gavl(lci, ci);
+    }
+  return 0;
+  }
+
+static void packet_lqt_2_gavl(lqt_packet_t * lp, gavl_packet_t * gp)
+  {
+  gavl_packet_alloc(gp, lp->data_len);
+  memcpy(gp->data, lp->data, lp->data_len);
+  gp->data_len = lp->data_len;
+  
+  gp->pts = lp->timestamp;
+  gp->duration = lp->duration;
+  gp->header_size = lp->header_size;
+
+  if(lp->flags & LQT_PACKET_KEYFRAME)
+    gp->flags |= GAVL_PACKET_KEYFRAME;
+
+  }
+
+int lqt_gavl_read_audio_packet(quicktime_t * file, int track, gavl_packet_t * p)
+  {
+  lqt_packet_t lp;
+  memset(&lp, 0, sizeof(lp));
+  if(!lqt_read_audio_packet(file, &lp, track))
+    return 0;
+  packet_lqt_2_gavl(&lp, p);
+  return 1;
+  }
+
+int lqt_gavl_read_video_packet(quicktime_t * file, int track, gavl_packet_t * p)
+  {
+  lqt_packet_t lp;
+  memset(&lp, 0, sizeof(lp));
+  if(!lqt_read_video_packet(file, &lp, track))
+    return 0;
+  packet_lqt_2_gavl(&lp, p);
+  return 1;
+  }
+
+static lqt_codec_info_t * find_encoder(lqt_codec_info_t ** infos,
+                                       lqt_compression_id_t id)
+  {
+  int i = 0;
+
+  while(infos[i])
+    {
+    if(infos[i]->compression_id == id)
+      return infos[i];
+    i++;
+    }
+  return NULL;
+  }
+
+
+int lqt_gavl_writes_compressed_audio(lqt_file_type_t type,
+                                     const gavl_audio_format_t * format,
+                                     const gavl_compression_info_t * ci)
+  {
+  int ret = 0;
+  lqt_compression_info_t lci;
+  lqt_codec_info_t ** infos;
+  lqt_codec_info_t * info;
+  
+  if(!compression_info_gavl_2_lqt(ci, format, NULL, &lci))
+    return 0;
+
+  infos = lqt_query_registry(1, 0, 1, 0);
+  info = find_encoder(infos, lci.id);
+
+  if(info)
+    ret = lqt_writes_compressed(type, &lci, info);
+  
+  lqt_destroy_codec_info(infos);
+
+  return ret;
+  }
+
+int lqt_gavl_writes_compressed_video(lqt_file_type_t type,
+                                     const gavl_video_format_t * format,
+                                     const gavl_compression_info_t * ci)
+  {
+  int ret = 0;
+  lqt_compression_info_t lci;
+  lqt_codec_info_t ** infos;
+  lqt_codec_info_t * info;
+  
+  if(!compression_info_gavl_2_lqt(ci, NULL, format, &lci))
+    return 0;
+  
+  infos = lqt_query_registry(0, 1, 1, 0);
+  info = find_encoder(infos, lci.id);
+
+  if(info)
+    ret = lqt_writes_compressed(type, &lci, info);
+  
+  lqt_destroy_codec_info(infos);
+
+  return ret;
+  }
+
+int lqt_gavl_add_audio_track_compressed(quicktime_t * file,
+                                        const gavl_audio_format_t * format,
+                                        const gavl_compression_info_t * ci)
+  {
+  lqt_codec_info_t ** infos;
+  lqt_codec_info_t * info;
+  lqt_compression_info_t lci;
+
+  compression_info_gavl_2_lqt(ci, format, NULL, &lci);
+  infos = lqt_query_registry(1, 0, 1, 0);
+  info = find_encoder(infos, lci.id);
+  lqt_add_audio_track_compressed(file, &lci, info);
+  lqt_destroy_codec_info(infos);
+  
+  return 1;
+  }
+
+
+int lqt_gavl_add_video_track_compressed(quicktime_t * file,
+                                        const gavl_video_format_t * format,
+                                        const gavl_compression_info_t * ci)
+  {
+  lqt_codec_info_t ** infos;
+  lqt_codec_info_t * info;
+  lqt_compression_info_t lci;
+
+  compression_info_gavl_2_lqt(ci, NULL, format, &lci);
+  infos = lqt_query_registry(0, 1, 1, 0);
+  info = find_encoder(infos, lci.id);
+  lqt_add_video_track_compressed(file, &lci, info);
+  lqt_destroy_codec_info(infos);
+  
+  return 1;
+  }
+
+static void packet_gavl_2_lqt(gavl_packet_t * gp, lqt_packet_t * lp)
+  {
+  memset(lp, 0, sizeof(*lp));
+  lp->data_len = gp->data_len;
+  lp->data = gp->data;
+  lp->timestamp = gp->pts;
+  lp->duration = gp->duration;
+  lp->header_size = gp->header_size;
+
+  if(gp->flags & GAVL_PACKET_KEYFRAME)
+    lp->flags |= LQT_PACKET_KEYFRAME;
+  }
+
+int lqt_gavl_write_audio_packet(quicktime_t * file, int track, gavl_packet_t * p)
+  {
+  lqt_packet_t lp;
+  packet_gavl_2_lqt(p, &lp);
+  return lqt_write_audio_packet(file, &lp, track);
+  }
+
+int lqt_gavl_write_video_packet(quicktime_t * file, int track, gavl_packet_t * p)
+  {
+  lqt_packet_t lp;
+  packet_gavl_2_lqt(p, &lp);
+  return lqt_write_video_packet(file, &lp, track);
+  }
