@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -20,6 +20,7 @@
  * *****************************************************************/
 
 #include <gavl/gavl.h>
+#include <gavl/compression.h>
 #include <lqt.h>
 
 /*! \mainpage
@@ -78,13 +79,30 @@ void lqt_gavl_rows_destroy(uint8_t** rows);
  * This function will change the format parameter according to
  * what you must pass to the encode calls. If the format is different
  * from the source format, you need a \ref gavl_audio_converter_t.
+ *
+ * You can pass NULL for the codec. In this case you must call
+ * \ref lqt_gavl_set_audio_codec later on.
+ * 
  */
 
-
 void lqt_gavl_add_audio_track(quicktime_t * file,
                                gavl_audio_format_t * format,
                                lqt_codec_info_t * codec);
 
+/** \ingroup encode
+ *  \brief Set up an audio stream for encoding
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param format Audio format
+ *  \param codec The codec to use
+ */
+
+void lqt_gavl_set_audio_codec(quicktime_t * file,
+                              int track,
+                              gavl_audio_format_t * format,
+                              lqt_codec_info_t * codec);
+
+
 /** \ingroup encode
  *  \brief Set up a video stream for encoding
  *  \param file A quicktime handle
@@ -99,12 +117,29 @@ void lqt_gavl_add_audio_track(quicktime_t * file,
  * If the video format contains a valid timecode format, a timecode track
  * will be added and attached to the video stream. If you don't like this,
  * set format->timecode_format.int_framerate to 0 before calling this function.
+ *
+ * You can pass NULL for the codec. In this case you must call
+ * \ref lqt_gavl_set_video_codec later on.
  */
 
 void lqt_gavl_add_video_track(quicktime_t * file,
                               gavl_video_format_t * format,
                               lqt_codec_info_t * codec);
 
+/** \ingroup encode
+ *  \brief Set up a video stream for encoding
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param format Video format (will be updated according to codec)
+ *  \param codec The codec to use
+ */
+
+void lqt_gavl_set_video_codec(quicktime_t * file,
+                              int track,
+                              gavl_video_format_t * format,
+                              lqt_codec_info_t * codec);
+
+
 /* Encode audio/video */
 
 /** \ingroup encode
@@ -231,3 +266,118 @@ void lqt_gavl_seek_scaled(quicktime_t * file, gavl_time_t * time, int scale);
  **/
 
 gavl_time_t lqt_gavl_duration(quicktime_t * file);
+
+/** \defgroup compression Functions for compressed frame I/O
+ */
+
+/** \ingroup compression
+ *  \brief Get audio compression info
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param ci Returns compression info
+ *  \returns 1 if a compression info was returned, 0 else
+ *
+ *  Free the returned info structure with \ref gavl_compression_info_free
+ */
+
+int lqt_gavl_get_audio_compression_info(quicktime_t * file, int track,
+                                        gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Get video compression info
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param ci Returns compression info
+ *  \returns 1 if a compression info was returned, 0 else
+ *
+ *  Free the returned info structure with \ref gavl_compression_info_free
+ */
+
+int lqt_gavl_get_video_compression_info(quicktime_t * file, int track,
+                                        gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Read an audio packet
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param p Packet
+ *  \returns 1 if a packet was read, 0 else
+ *
+ */
+
+int lqt_gavl_read_audio_packet(quicktime_t * file, int track, gavl_packet_t * p);
+
+/** \ingroup compression
+ *  \brief Read a video packet
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param p Packet
+ *  \returns 1 if a packet was read, 0 else
+ *
+ */
+
+int lqt_gavl_read_video_packet(quicktime_t * file, int track, gavl_packet_t * p);
+
+/** \ingroup compression
+ *  \brief Check if a compressed audio stream is supported 
+ *  \param type File type
+ *  \param format Audio format
+ *  \param ci Compression info
+ *  \returns 1 if writing compressed packets is supported, 0 else
+ */
+
+int lqt_gavl_writes_compressed_audio(lqt_file_type_t type,
+                                     const gavl_audio_format_t * format,
+                                     const gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Check if a compressed video stream is supported 
+ *  \param type File type
+ *  \param format Video format
+ *  \param ci Compression info
+ *  \returns 1 if writing compressed packets is supported, 0 else
+ */
+
+int lqt_gavl_writes_compressed_video(lqt_file_type_t type,
+                                     const gavl_video_format_t * format,
+                                     const gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Add an audio stream for compressed writing 
+ *  \param file A quicktime handle
+ *  \param format Audio format
+ *  \param ci Compression info
+ */
+
+int lqt_gavl_add_audio_track_compressed(quicktime_t * file,
+                                        const gavl_audio_format_t * format,
+                                        const gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Add a video stream for compressed writing 
+ *  \param file A quicktime handle
+ *  \param format Video format
+ *  \param ci Compression info
+ */
+
+int lqt_gavl_add_video_track_compressed(quicktime_t * file,
+                                        const gavl_video_format_t * format,
+                                        const gavl_compression_info_t * ci);
+
+/** \ingroup compression
+ *  \brief Write an audio packet 
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param p Packet
+ */
+
+int lqt_gavl_write_audio_packet(quicktime_t * file, int track, gavl_packet_t * p);
+
+/** \ingroup compression
+ *  \brief Write a video packet 
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param p Packet
+ */
+
+int lqt_gavl_write_video_packet(quicktime_t * file, int track, gavl_packet_t * p);
