@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -410,7 +410,7 @@ static int open_oss(void * data, gavl_audio_format_t * format)
     format->samples_per_frame = 1024;
     priv->bytes_per_sample =
       gavl_bytes_per_sample(format->sample_format);
-    gavl_audio_format_copy(&(priv->format), format);
+    gavl_audio_format_copy(&priv->format, format);
     }
   return ret;
   }
@@ -447,7 +447,7 @@ static int start_oss(void * data)
 
   if((priv->fd_front == -1) && (priv->fd_rear == -1)
      && (priv->fd_center_lfe == -1))
-    return open_devices(priv, &(priv->format));
+    return open_devices(priv, &priv->format);
   else
     return 1;
   }
