@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -788,6 +788,12 @@ static int read_image_tiff(void *priv, gavl_video_frame_t *frame)
   tdata_t buf;
   int num_planes;
 
+  if(!frame)
+    {
+    TIFFClose( p->tiff );
+    return 1;
+    }
+  
   num_planes = p->is_planar ? p->SamplesPerPixel : 1;
   
   p->buffer_position =0;
