@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -175,7 +175,8 @@ static const bg_parameter_info_t info_1[] =
       .type =        BG_PARAMETER_CHECKBUTTON,
       .flags =     PARAMETER_FLAGS,
       .val_default = { .val_i = 1 },
-      .help_string = "Checkbutton help"
+      .help_string = "Checkbutton help",
+      .preset_path = "test1",
     },
     {
       .name =        "button",
@@ -256,8 +257,14 @@ static const bg_parameter_info_t info_1[] =
       .type =        BG_PARAMETER_STRINGLIST,
       .flags =     PARAMETER_FLAGS,
       .val_default = { .val_str = "option_2" },
-      .multi_names =  (char const *[]){ "option_1", "option_2", "option_3", NULL },
-      .multi_labels = (char const *[]){ "Option 1", "Option 2", "Option 3", NULL },
+      .multi_names =  (char const *[]){ "option_1",
+                                        "option_2",
+                                        "option_3",
+                                        NULL },
+      .multi_labels = (char const *[]){ "Option 1",
+                                        "Option 2",
+                                        "Option 3",
+                                        NULL },
       .help_string =   "Stringlist help"
     },
     { /* End of parameters */ }
@@ -279,6 +286,7 @@ static const bg_parameter_info_t info_2[] =
       .flags =     PARAMETER_FLAGS,
       .val_default = { .val_color = { 0.0, 1.0, 0.0 } },
       .help_string =   "Color RGB help",
+      .preset_path = "test2",
     },
     {
       .name =      "color_rgba",
@@ -353,6 +361,7 @@ static const bg_parameter_info_t info_3[] =
       .multi_descriptions = (char const *[]){ "Multimenu 1", "Multimenu 2", NULL },
       .multi_parameters =   multimenu_parameters,
       .help_string =   "Multimenu help",
+      .preset_path = "test3",
     },
 #if 1
     {
@@ -383,6 +392,7 @@ static const bg_parameter_info_t info_4[] =
       .multi_descriptions = (char const *[]){ "Multichain 1", "Multichain 2", NULL },
       .multi_parameters =   multichain_parameters,
       .help_string =   "Multichain help",
+      .preset_path = "test4",
     },
     { /* End of parameters */ }
   };
@@ -408,7 +418,7 @@ static const bg_parameter_info_t * find_parameter(const bg_parameter_info_t * ar
     
     if(!strcmp(arr[i].name, name))
       {
-      return &(arr[i]);
+      return &arr[i];
       break;
       }
     else if(arr[i].multi_parameters)
